You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@pekko.apache.org by fa...@apache.org on 2023/02/18 11:56:51 UTC

[incubator-pekko-http] branch main updated: Deprecation versions (#71)

This is an automated email from the ASF dual-hosted git repository.

fanningpj pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/incubator-pekko-http.git


The following commit(s) were added to refs/heads/main by this push:
     new fa711bfbb Deprecation versions (#71)
fa711bfbb is described below

commit fa711bfbb49edfd24e323f77806ee0e0bbffb2a2
Author: PJ Fanning <pj...@users.noreply.github.com>
AuthorDate: Sat Feb 18 12:56:46 2023 +0100

    Deprecation versions (#71)
    
    * update deprecation versions to mention Akka
    
    * scalafmt
---
 docs/src/main/paradox/compatibility-guidelines.md  | 10 +----
 .../main/paradox/routing-dsl/exception-handling.md |  2 +-
 docs/src/main/paradox/routing-dsl/rejections.md    |  2 +-
 .../apache/pekko/http/javadsl/model/FormData.java  |  2 +-
 .../http/javadsl/model/headers/RemoteAddress.java  |  2 +-
 http-core/src/main/resources/reference.conf        |  2 +-
 .../pekko/http/javadsl/ConnectionContext.scala     | 21 ++++++-----
 .../scala/org/apache/pekko/http/javadsl/Http.scala | 44 +++++++++++-----------
 .../http/javadsl/model/ws/UpgradeToWebSocket.scala |  4 +-
 .../http/javadsl/settings/ParserSettings.scala     |  6 +--
 .../http/javadsl/settings/ServerSettings.scala     |  8 ++--
 .../pekko/http/scaladsl/ConnectionContext.scala    | 36 +++++++++---------
 .../pekko/http/scaladsl/model/FormData.scala       |  2 +-
 .../pekko/http/scaladsl/model/HttpEntity.scala     |  4 +-
 .../pekko/http/scaladsl/model/HttpMessage.scala    |  8 ++--
 .../pekko/http/scaladsl/model/MediaType.scala      |  6 +--
 .../pekko/http/scaladsl/model/StatusCode.scala     | 10 ++---
 .../http/scaladsl/model/headers/HttpCookie.scala   |  8 ++--
 .../scaladsl/model/ws/UpgradeToWebSocket.scala     |  2 +-
 .../scaladsl/settings/ConnectionPoolSettings.scala |  2 +-
 .../http/scaladsl/settings/ParserSettings.scala    |  4 +-
 .../http/scaladsl/settings/ServerSettings.scala    | 10 ++---
 .../apache/pekko/http/javadsl/coding/Coder.java    |  2 +-
 .../apache/pekko/http/javadsl/server/HttpApp.java  |  2 +-
 .../http/impl/settings/RoutingSettingsImpl.scala   |  2 +-
 .../server/directives/RouteDirectives.scala        |  2 +-
 .../server/directives/WebSocketDirectives.scala    |  4 +-
 .../http/javadsl/settings/RoutingSettings.scala    |  4 +-
 .../sse/EventStreamUnmarshalling.scala             |  4 +-
 .../pekko/http/scaladsl/coding/Decoder.scala       |  2 +-
 .../pekko/http/scaladsl/coding/Deflate.scala       |  6 +--
 .../http/scaladsl/coding/DeflateCompressor.scala   |  2 +-
 .../pekko/http/scaladsl/coding/Encoder.scala       |  8 ++--
 .../apache/pekko/http/scaladsl/coding/Gzip.scala   |  6 +--
 .../pekko/http/scaladsl/coding/NoCoding.scala      |  5 ++-
 .../pekko/http/scaladsl/server/HttpApp.scala       |  2 +-
 .../pekko/http/scaladsl/server/Rejection.scala     | 10 ++---
 .../apache/pekko/http/scaladsl/server/Route.scala  |  6 +--
 .../pekko/http/scaladsl/server/RouteResult.scala   |  4 +-
 .../server/directives/FormFieldDirectives.scala    | 22 ++++++-----
 .../server/directives/HeaderDirectives.scala       |  8 ++--
 .../server/directives/ParameterDirectives.scala    | 21 +++++++----
 .../server/directives/WebSocketDirectives.scala    |  2 +-
 .../http/scaladsl/settings/RoutingSettings.scala   |  6 +--
 .../http/scaladsl/unmarshalling/Unmarshaller.scala |  8 ++--
 .../sse/EventStreamUnmarshalling.scala             |  6 +--
 46 files changed, 174 insertions(+), 165 deletions(-)

diff --git a/docs/src/main/paradox/compatibility-guidelines.md b/docs/src/main/paradox/compatibility-guidelines.md
index c3181a7d7..c73965384 100644
--- a/docs/src/main/paradox/compatibility-guidelines.md
+++ b/docs/src/main/paradox/compatibility-guidelines.md
@@ -112,15 +112,7 @@ Java
   
 ## Versioning and Compatibility
 
-Starting from version 10.1.0, there will be two active release branches:
-- The "current" release line (in `main`), where we will basically continue to evolve Apache Pekko HTTP in the same way as currently. New features will be introduced here incrementally.
-- The "previous" release line (in a release-10.x branch), where the focus is on stability. We will continue to maintain the previous release by fixing serious bugs but it will not see new features. Previous releases will see less frequent releases over time.
-
-It is planned to rotate versions in an annual fashion. Meaning a new minor version will be created every year.
-Whenever a new minor version is created, it will move the at that point current minor version release series over into maintenance mode, making it the "previous".
-The former "previous" release has reached its end of life at this point. This way every release line is supported for two years.
-
-The Apache Pekko HTTP Team currently does not intend to break binary compatibility, i.e. no binary incompatible 11.x.y release is currently planned.
+The Apache Pekko HTTP Team currently does not intend to break binary compatibility, i.e. no binary incompatible 2.x.y release is currently planned.
     
 ## Specific versions inter-op discussion
 
diff --git a/docs/src/main/paradox/routing-dsl/exception-handling.md b/docs/src/main/paradox/routing-dsl/exception-handling.md
index 2723fe107..ec690082f 100644
--- a/docs/src/main/paradox/routing-dsl/exception-handling.md
+++ b/docs/src/main/paradox/routing-dsl/exception-handling.md
@@ -89,7 +89,7 @@ have a read at this excellent post by A. Shipilёv: [The Exceptional Performance
 
 
 @@@ note
-Please note that since version `10.1.6`, the default `ExceptionHandler` will also discard the entity bytes automatically. If you want to change this behavior,
+Please note that the default `ExceptionHandler` will also discard the entity bytes automatically. If you want to change this behavior,
 please refer to @ref[the section above](exception-handling.md#exception-handling); however, might cause connections to stall
 if the entity is not properly rejected or cancelled on the client side.
 @@@
diff --git a/docs/src/main/paradox/routing-dsl/rejections.md b/docs/src/main/paradox/routing-dsl/rejections.md
index c6e9779b1..73cf38d5c 100644
--- a/docs/src/main/paradox/routing-dsl/rejections.md
+++ b/docs/src/main/paradox/routing-dsl/rejections.md
@@ -42,7 +42,7 @@ will handle *all* rejections that reach it.
 
 
 @@@ note
-Please note that since version `10.1.2`, the default `RejectionHandler` will also discard the entity bytes automatically. If you want to change this behavior,
+Please note that the default `RejectionHandler` will also discard the entity bytes automatically. If you want to change this behavior,
 please refer to @ref[Customising rejection HTTP Responses](rejections.md#customising-rejections); however, might cause connections to stall
 if the entity is not properly rejected or cancelled on the client side.
 @@@
diff --git a/http-core/src/main/java/org/apache/pekko/http/javadsl/model/FormData.java b/http-core/src/main/java/org/apache/pekko/http/javadsl/model/FormData.java
index 45bbe1dfc..82ffd8926 100644
--- a/http-core/src/main/java/org/apache/pekko/http/javadsl/model/FormData.java
+++ b/http-core/src/main/java/org/apache/pekko/http/javadsl/model/FormData.java
@@ -32,7 +32,7 @@ public final class FormData {
    * @deprecated FormData always uses charset UTF-8 without appending the charset to
    *             'Content-Type: application/x-www-form-urlencoded', use toEntity() instead.
    */
-  @Deprecated // since 10.1.8
+  @Deprecated // since Akka HTTP 10.1.8
   public RequestEntity toEntity(HttpCharset charset) {
     return HttpEntities.create(ContentTypes.APPLICATION_X_WWW_FORM_URLENCODED, fields.render(charset));
   }
diff --git a/http-core/src/main/java/org/apache/pekko/http/javadsl/model/headers/RemoteAddress.java b/http-core/src/main/java/org/apache/pekko/http/javadsl/model/headers/RemoteAddress.java
index ecc450d63..8ab7518af 100644
--- a/http-core/src/main/java/org/apache/pekko/http/javadsl/model/headers/RemoteAddress.java
+++ b/http-core/src/main/java/org/apache/pekko/http/javadsl/model/headers/RemoteAddress.java
@@ -8,7 +8,7 @@ package org.apache.pekko.http.javadsl.model.headers;
  *  Model for the `Remote-Address` header.
  *  Custom header we use for optionally transporting the peer's IP in an HTTP header.
  *
- *  Deprecated since 10.2.0: use the remote-header-attribute instead.
+ *  Deprecated since Akka HTTP 10.2.0: use the remote-header-attribute instead.
  */
 @Deprecated
 public abstract class RemoteAddress extends org.apache.pekko.http.scaladsl.model.HttpHeader {
diff --git a/http-core/src/main/resources/reference.conf b/http-core/src/main/resources/reference.conf
index 4cfb4d57b..1472e4172 100644
--- a/http-core/src/main/resources/reference.conf
+++ b/http-core/src/main/resources/reference.conf
@@ -99,7 +99,7 @@ akka.http {
 
     # Enables/disables the addition of a `Remote-Address` header
     # holding the clients (remote) IP address.
-    # Deprecated since 10.2.0: please use `remote-address-attribute` instead.
+    # Deprecated since Akka HTTP 10.2.0: please use `remote-address-attribute` instead.
     remote-address-header = off
 
     # Enables/disables the addition of a remote-address attribute in HttpRequest
diff --git a/http-core/src/main/scala/org/apache/pekko/http/javadsl/ConnectionContext.scala b/http-core/src/main/scala/org/apache/pekko/http/javadsl/ConnectionContext.scala
index d72258991..88261ffd2 100644
--- a/http-core/src/main/scala/org/apache/pekko/http/javadsl/ConnectionContext.scala
+++ b/http-core/src/main/scala/org/apache/pekko/http/javadsl/ConnectionContext.scala
@@ -52,13 +52,15 @@ object ConnectionContext {
 
   // ConnectionContext
   /** Used to serve HTTPS traffic. */
-  @Deprecated @deprecated("use httpsServer, httpsClient or the method that takes a custom factory", since = "10.2.0")
+  @Deprecated @deprecated("use httpsServer, httpsClient or the method that takes a custom factory",
+    since = "Akka HTTP 10.2.0")
   def https(sslContext: SSLContext): HttpsConnectionContext = // ...
     // #https-context-creation
     scaladsl.ConnectionContext.https(sslContext)
 
   /** Used to serve HTTPS traffic. */
-  @Deprecated @deprecated("use httpsServer, httpsClient or the method that takes a custom factory", since = "10.2.0")
+  @Deprecated @deprecated("use httpsServer, httpsClient or the method that takes a custom factory",
+    since = "Akka HTTP 10.2.0")
   def https(
       sslContext: SSLContext,
       sslConfig: Optional[PekkoSSLConfig],
@@ -76,7 +78,8 @@ object ConnectionContext {
       OptionConverters.toScala(sslParameters))
 
   /** Used to serve HTTPS traffic. */
-  @Deprecated @deprecated("use httpsServer, httpsClient or the method that takes a custom factory", since = "10.2.0")
+  @Deprecated @deprecated("use httpsServer, httpsClient or the method that takes a custom factory",
+    since = "Akka HTTP 10.2.0")
   def https(
       sslContext: SSLContext,
       enabledCipherSuites: Optional[JCollection[String]],
@@ -100,7 +103,7 @@ object ConnectionContext {
 abstract class ConnectionContext {
   def isSecure: Boolean
   @Deprecated
-  @deprecated("Not always available", since = "10.2.0")
+  @deprecated("Not always available", since = "Akka HTTP 10.2.0")
   def sslConfig: Option[PekkoSSLConfig]
 }
 
@@ -115,22 +118,22 @@ abstract class HttpsConnectionContext extends pekko.http.javadsl.ConnectionConte
   override final def isSecure = true
 
   /** Java API */
-  @Deprecated @deprecated("here for binary compatibility", since = "10.2.0")
+  @Deprecated @deprecated("here for binary compatibility", since = "Akka HTTP 10.2.0")
   def getEnabledCipherSuites: Optional[JCollection[String]]
 
   /** Java API */
-  @Deprecated @deprecated("here for binary compatibility", since = "10.2.0")
+  @Deprecated @deprecated("here for binary compatibility", since = "Akka HTTP 10.2.0")
   def getEnabledProtocols: Optional[JCollection[String]]
 
   /** Java API */
-  @Deprecated @deprecated("here for binary compatibility", since = "10.2.0")
+  @Deprecated @deprecated("here for binary compatibility", since = "Akka HTTP 10.2.0")
   def getClientAuth: Optional[TLSClientAuth]
 
   /** Java API */
-  @Deprecated @deprecated("here for binary compatibility, not always available", since = "10.2.0")
+  @Deprecated @deprecated("here for binary compatibility, not always available", since = "Akka HTTP 10.2.0")
   def getSslContext: SSLContext
 
   /** Java API */
-  @Deprecated @deprecated("here for binary compatibility", since = "10.2.0")
+  @Deprecated @deprecated("here for binary compatibility", since = "Akka HTTP 10.2.0")
   def getSslParameters: Optional[SSLParameters]
 }
diff --git a/http-core/src/main/scala/org/apache/pekko/http/javadsl/settings/ParserSettings.scala b/http-core/src/main/scala/org/apache/pekko/http/javadsl/settings/ParserSettings.scala
index 767f84b8c..3f486cdc0 100644
--- a/http-core/src/main/scala/org/apache/pekko/http/javadsl/settings/ParserSettings.scala
+++ b/http-core/src/main/scala/org/apache/pekko/http/javadsl/settings/ParserSettings.scala
@@ -114,21 +114,21 @@ object ParserSettings extends SettingsCompanion[ParserSettings] {
    * @deprecated Use forServer or forClient instead.
    */
   @Deprecated
-  @deprecated("Use forServer or forClient instead", since = "10.2.0")
+  @deprecated("Use forServer or forClient instead", since = "Akka HTTP 10.2.0")
   override def create(config: Config): ParserSettings = ParserSettingsImpl(config)
 
   /**
    * @deprecated Use forServer or forClient instead.
    */
   @Deprecated
-  @deprecated("Use forServer or forClient instead", since = "10.2.0")
+  @deprecated("Use forServer or forClient instead", since = "Akka HTTP 10.2.0")
   override def create(configOverrides: String): ParserSettings = ParserSettingsImpl(configOverrides)
 
   /**
    * @deprecated Use forServer or forClient instead.
    */
   @Deprecated
-  @deprecated("Use forServer or forClient instead", since = "10.2.0")
+  @deprecated("Use forServer or forClient instead", since = "Akka HTTP 10.2.0")
   @nowarn("msg=create overrides concrete, non-deprecated symbol")
   override def create(system: ActorSystem): ParserSettings = create(system.settings.config)
 
diff --git a/http-core/src/main/scala/org/apache/pekko/http/scaladsl/ConnectionContext.scala b/http-core/src/main/scala/org/apache/pekko/http/scaladsl/ConnectionContext.scala
index 81f78e770..328a1a7a0 100644
--- a/http-core/src/main/scala/org/apache/pekko/http/scaladsl/ConnectionContext.scala
+++ b/http-core/src/main/scala/org/apache/pekko/http/scaladsl/ConnectionContext.scala
@@ -19,7 +19,7 @@ import scala.collection.immutable
 import scala.compat.java8.OptionConverters._
 
 trait ConnectionContext extends pekko.http.javadsl.ConnectionContext {
-  @deprecated("Internal method, left for binary compatibility", since = "10.2.0")
+  @deprecated("Internal method, left for binary compatibility", since = "Akka HTTP 10.2.0")
   protected[http] def defaultPort: Int
 }
 
@@ -80,7 +80,7 @@ object ConnectionContext {
       case Some((host, port)) => createSSLEngine(host, port)
     }: Option[(String, Int)] => SSLEngine))
 
-  @deprecated("use httpsClient, httpsServer, or the lower-level SSLEngine-based constructor", "10.2.0")
+  @deprecated("use httpsClient, httpsServer, or the lower-level SSLEngine-based constructor", "Akka HTTP 10.2.0")
   def https(
       sslContext: SSLContext,
       sslConfig: Option[PekkoSSLConfig] = None,
@@ -94,7 +94,7 @@ object ConnectionContext {
   def noEncryption() = HttpConnectionContext
 }
 
-@deprecated("here to be able to keep supporting the old API", since = "10.2.0")
+@deprecated("here to be able to keep supporting the old API", since = "Akka HTTP 10.2.0")
 private[http] case class DeprecatedSslContextParameters(
     sslContext: SSLContext,
     sslConfig: Option[PekkoSSLConfig],
@@ -112,13 +112,13 @@ private[http] case class DeprecatedSslContextParameters(
  * This constructor is INTERNAL API, use ConnectionContext.https instead
  */
 @InternalApi
-@nowarn("msg=since 10.2.0")
+@nowarn("msg=since Akka HTTP 10.2.0")
 final class HttpsConnectionContext private[http] (
     private[http] val sslContextData: Either[DeprecatedSslContextParameters, Option[(String, Int)] => SSLEngine])
     extends pekko.http.javadsl.HttpsConnectionContext with ConnectionContext {
   protected[http] override final def defaultPort: Int = 443
 
-  @deprecated("prefer ConnectionContext.httpsClient or ConnectionContext.httpsServer", "10.2.0")
+  @deprecated("prefer ConnectionContext.httpsClient or ConnectionContext.httpsServer", "Akka HTTP 10.2.0")
   def this(
       sslContext: SSLContext,
       sslConfig: Option[PekkoSSLConfig] = None,
@@ -128,31 +128,33 @@ final class HttpsConnectionContext private[http] (
       sslParameters: Option[SSLParameters] = None) = this(Left(DeprecatedSslContextParameters(sslContext, sslConfig,
     enabledCipherSuites, enabledProtocols, clientAuth, sslParameters)))
 
-  @deprecated("not always available", "10.2.0") def sslContext: SSLContext = sslContextData.left.get.sslContext
-  @deprecated("here for binary compatibility", since = "10.2.0") def sslConfig: Option[PekkoSSLConfig] =
+  @deprecated("not always available", "Akka HTTP 10.2.0") def sslContext: SSLContext =
+    sslContextData.left.get.sslContext
+  @deprecated("here for binary compatibility", since = "Akka HTTP 10.2.0") def sslConfig: Option[PekkoSSLConfig] =
     sslContextData.left.get.sslConfig
-  @deprecated("here for binary compatibility", since = "10.2.0") def enabledCipherSuites
+  @deprecated("here for binary compatibility", since = "Akka HTTP 10.2.0") def enabledCipherSuites
       : Option[immutable.Seq[String]] = sslContextData.left.get.enabledCipherSuites
-  @deprecated("here for binary compatibility", since = "10.2.0") def enabledProtocols: Option[immutable.Seq[String]] =
+  @deprecated("here for binary compatibility", since = "Akka HTTP 10.2.0") def enabledProtocols
+      : Option[immutable.Seq[String]] =
     sslContextData.left.get.enabledProtocols
-  @deprecated("here for binary compatibility", since = "10.2.0") def clientAuth: Option[TLSClientAuth] =
+  @deprecated("here for binary compatibility", since = "Akka HTTP 10.2.0") def clientAuth: Option[TLSClientAuth] =
     sslContextData.left.get.clientAuth
-  @deprecated("here for binary compatibility", since = "10.2.0") def sslParameters: Option[SSLParameters] =
+  @deprecated("here for binary compatibility", since = "Akka HTTP 10.2.0") def sslParameters: Option[SSLParameters] =
     sslContextData.left.get.sslParameters
 
-  @deprecated("here for binary compatibility", since = "10.2.0")
+  @deprecated("here for binary compatibility", since = "Akka HTTP 10.2.0")
   private[http] def firstSession = NegotiateNewSession(enabledCipherSuites, enabledProtocols, clientAuth, sslParameters)
 
-  @deprecated("not always available", "10.2.0")
+  @deprecated("not always available", "Akka HTTP 10.2.0")
   override def getSslContext = sslContext
-  @deprecated("here for binary compatibility", since = "10.2.0")
+  @deprecated("here for binary compatibility", since = "Akka HTTP 10.2.0")
   override def getEnabledCipherSuites: Optional[JCollection[String]] =
     enabledCipherSuites.map(_.asJavaCollection).asJava
-  @deprecated("here for binary compatibility", since = "10.2.0")
+  @deprecated("here for binary compatibility", since = "Akka HTTP 10.2.0")
   override def getEnabledProtocols: Optional[JCollection[String]] = enabledProtocols.map(_.asJavaCollection).asJava
-  @deprecated("here for binary compatibility", since = "10.2.0")
+  @deprecated("here for binary compatibility", since = "Akka HTTP 10.2.0")
   override def getClientAuth: Optional[TLSClientAuth] = clientAuth.asJava
-  @deprecated("here for binary compatibility", since = "10.2.0")
+  @deprecated("here for binary compatibility", since = "Akka HTTP 10.2.0")
   override def getSslParameters: Optional[SSLParameters] = sslParameters.asJava
 }
 
diff --git a/http-core/src/main/scala/org/apache/pekko/http/scaladsl/model/FormData.scala b/http-core/src/main/scala/org/apache/pekko/http/scaladsl/model/FormData.scala
index b1626a43c..698b1d04d 100644
--- a/http-core/src/main/scala/org/apache/pekko/http/scaladsl/model/FormData.scala
+++ b/http-core/src/main/scala/org/apache/pekko/http/scaladsl/model/FormData.scala
@@ -18,7 +18,7 @@ final case class FormData(fields: Uri.Query) {
 
   @deprecated(
     "FormData always uses charset UTF-8 without appending the charset to 'Content-Type: application/x-www-form-urlencoded', use toEntity instead.",
-    "10.1.7")
+    "Akka HTTP 10.1.7")
   def toEntity(charset: HttpCharset): pekko.http.scaladsl.model.RequestEntity =
     toEntityWithCharset(charset)
 
diff --git a/http-core/src/main/scala/org/apache/pekko/http/scaladsl/model/HttpEntity.scala b/http-core/src/main/scala/org/apache/pekko/http/scaladsl/model/HttpEntity.scala
index 90ec5dc21..01a785c5d 100644
--- a/http-core/src/main/scala/org/apache/pekko/http/scaladsl/model/HttpEntity.scala
+++ b/http-core/src/main/scala/org/apache/pekko/http/scaladsl/model/HttpEntity.scala
@@ -626,14 +626,14 @@ object HttpEntity {
   /**
    * Deprecated: no-op, not explicitly needed any more.
    */
-  @deprecated("Not needed explicitly any more. ", "10.1.5")
+  @deprecated("Not needed explicitly any more. ", "Akka HTTP 10.1.5")
   def limitableByteSource[Mat](source: Source[ByteString, Mat]): Source[ByteString, Mat] =
     source
 
   /**
    * Deprecated: no-op, not explicitly needed any more.
    */
-  @deprecated("Not needed explicitly any more. ", "10.1.5")
+  @deprecated("Not needed explicitly any more. ", "Akka HTTP 10.1.5")
   def limitableChunkSource[Mat](source: Source[ChunkStreamPart, Mat]): Source[ChunkStreamPart, Mat] =
     source
 
diff --git a/http-core/src/main/scala/org/apache/pekko/http/scaladsl/model/HttpMessage.scala b/http-core/src/main/scala/org/apache/pekko/http/scaladsl/model/HttpMessage.scala
index 61e584b4a..190ed4134 100644
--- a/http-core/src/main/scala/org/apache/pekko/http/scaladsl/model/HttpMessage.scala
+++ b/http-core/src/main/scala/org/apache/pekko/http/scaladsl/model/HttpMessage.scala
@@ -342,7 +342,7 @@ final class HttpRequest(
   override def isRequest = true
   override def isResponse = false
 
-  @deprecated("use the constructor that includes an attributes parameter instead", "10.2.0")
+  @deprecated("use the constructor that includes an attributes parameter instead", "Akka HTTP 10.2.0")
   private[model] def this(method: HttpMethod, uri: Uri, headers: immutable.Seq[HttpHeader], entity: RequestEntity,
       protocol: HttpProtocol) =
     this(method, uri, headers, Map.empty, entity, protocol)
@@ -407,7 +407,7 @@ final class HttpRequest(
 
   /* Manual Case Class things, to easen bin-compat */
 
-  @deprecated("Use the `withXYZ` methods instead. Kept for binary compatibility", "10.2.0")
+  @deprecated("Use the `withXYZ` methods instead. Kept for binary compatibility", "Akka HTTP 10.2.0")
   def copy(
       method: HttpMethod = method,
       uri: Uri = uri,
@@ -554,7 +554,7 @@ final class HttpResponse(
   override def isRequest = false
   override def isResponse = true
 
-  @deprecated("use the constructor that includes an attributes parameter instead", "10.2.0")
+  @deprecated("use the constructor that includes an attributes parameter instead", "Akka HTTP 10.2.0")
   private[model] def this(status: StatusCode, headers: immutable.Seq[HttpHeader], entity: ResponseEntity,
       protocol: HttpProtocol) =
     this(status, headers, Map.empty, entity, protocol)
@@ -587,7 +587,7 @@ final class HttpResponse(
     copyImpl(entity = entity.transformDataBytes(Flow.fromGraph(transformer)))
 
   /* Manual Case Class things, to ease bin-compat */
-  @deprecated("Use the `withXYZ` methods instead", "10.2.0")
+  @deprecated("Use the `withXYZ` methods instead", "Akka HTTP 10.2.0")
   def copy(
       status: StatusCode = status,
       headers: immutable.Seq[HttpHeader] = headers,
diff --git a/http-core/src/main/scala/org/apache/pekko/http/scaladsl/model/MediaType.scala b/http-core/src/main/scala/org/apache/pekko/http/scaladsl/model/MediaType.scala
index 3bea65abe..68a1f4dd3 100644
--- a/http-core/src/main/scala/org/apache/pekko/http/scaladsl/model/MediaType.scala
+++ b/http-core/src/main/scala/org/apache/pekko/http/scaladsl/model/MediaType.scala
@@ -358,9 +358,9 @@ object MediaTypes extends ObjectRegistry[(String, String), MediaType] {
   val `application/atom+xml`                                                      = awoc("atom+xml", "atom")
   val `application/base64`                                                        = awoc("base64", "mm", "mme")
   val `application/cbor`                                                          = abin("cbor", Compressible, "cbor")
-  @deprecated("This format is unofficial and should not be used. Use application/vnd.ms-excel instead.", "10.1.6")
+  @deprecated("This format is unofficial and should not be used. Use application/vnd.ms-excel instead.", "Akka HTTP 10.1.6")
   val `application/excel`                                                         = abin("excel", NotCompressible)
-  @deprecated("This format is unofficial and should not be used. Use font/woff instead.", "10.1.7")
+  @deprecated("This format is unofficial and should not be used. Use font/woff instead.", "Akka HTTP 10.1.7")
   val `application/font-woff`                                                     = abin("font-woff", NotCompressible)
   val `application/gnutar`                                                        = abin("gnutar", NotCompressible, "tgz")
   val `application/java-archive`                                                  = abin("java-archive", NotCompressible, "jar", "war", "ear")
@@ -372,7 +372,7 @@ object MediaTypes extends ObjectRegistry[(String, String), MediaType] {
   val `application/grpc+proto`                                                    = abin("grpc+proto", NotCompressible)
   val `application/lha`                                                           = abin("lha", NotCompressible, "lha")
   val `application/lzx`                                                           = abin("lzx", NotCompressible, "lzx")
-  @deprecated("This format is unofficial and should not be used. Use application/vnd.ms-powerpoint instead.", "10.1.6")
+  @deprecated("This format is unofficial and should not be used. Use application/vnd.ms-powerpoint instead.", "Akka HTTP 10.1.6")
   val `application/mspowerpoint`                                                  = abin("mspowerpoint", NotCompressible)
   val `application/msword`                                                        = abin("msword", NotCompressible, "doc", "dot", "w6w", "wiz", "word", "wri")
   val `application/octet-stream`                                                  = abin("octet-stream", NotCompressible, "a", "bin", "class", "dump", "exe", "lhx", "lzh", "o", "psd", "saveme", "zoo")
diff --git a/http-core/src/main/scala/org/apache/pekko/http/scaladsl/model/StatusCode.scala b/http-core/src/main/scala/org/apache/pekko/http/scaladsl/model/StatusCode.scala
index c2f366caf..52104bc20 100644
--- a/http-core/src/main/scala/org/apache/pekko/http/scaladsl/model/StatusCode.scala
+++ b/http-core/src/main/scala/org/apache/pekko/http/scaladsl/model/StatusCode.scala
@@ -143,14 +143,14 @@ object StatusCodes extends ObjectRegistry[Int, StatusCode] {
   val LengthRequired               = reg(c(411)("Length Required", "The request did not specify the length of its content, which is required by the requested resource."))
   val PreconditionFailed           = reg(c(412)("Precondition Failed", "The server does not meet one of the preconditions that the requester put on the request."))
   val PayloadTooLarge              = reg(c(413)("Payload Too Large", "The request payload is larger than the server is willing or able to process."))
-  @deprecated("deprecated in favor of PayloadTooLarge", "10.1.11")
+  @deprecated("deprecated in favor of PayloadTooLarge", "Akka HTTP 10.1.11")
   val RequestEntityTooLarge        = PayloadTooLarge
   val UriTooLong                   = reg(c(414)("URI Too Long", "The URI provided was too long for the server to process."))
-  @deprecated("deprecated in favor of UriTooLong", "10.1.11")
+  @deprecated("deprecated in favor of UriTooLong", "Akka HTTP 10.1.11")
   val RequestUriTooLong            = UriTooLong
   val UnsupportedMediaType         = reg(c(415)("Unsupported Media Type", "The request entity has a media type which the server or resource does not support."))
   val RangeNotSatisfiable          = reg(c(416)("Range Not Satisfiable", "The client has asked for a portion of the file, but the server cannot supply that portion."))
-  @deprecated("deprecated in favor of RangeNotSatisfiable", "10.1.11")
+  @deprecated("deprecated in favor of RangeNotSatisfiable", "Akka HTTP 10.1.11")
   val RequestedRangeNotSatisfiable = RangeNotSatisfiable
   val ExpectationFailed            = reg(c(417)("Expectation Failed", "The server cannot meet the requirements of the Expect request-header field."))
   val ImATeapot                    = reg(c(418)("I'm a teapot", "The resulting entity body MAY be short and stout."))
@@ -160,7 +160,7 @@ object StatusCodes extends ObjectRegistry[Int, StatusCode] {
   val Locked                       = reg(c(423)("Locked", "The resource that is being accessed is locked."))
   val FailedDependency             = reg(c(424)("Failed Dependency", "The request failed due to failure of a previous request."))
   val TooEarly                     = reg(c(425)("Too Early", "The server is unwilling to risk processing a request that might be replayed.")) // RFC 8470
-  @deprecated("Non-standard Unordered Collection should not be used, deprecated in favor of TooEarly", "10.1.6")
+  @deprecated("Non-standard Unordered Collection should not be used, deprecated in favor of TooEarly", "Akka HTTP 10.1.6")
   val UnorderedCollection          = TooEarly
   val UpgradeRequired              = reg(c(426)("Upgrade Required", "The client should switch to a different protocol."))
   val PreconditionRequired         = reg(c(428)("Precondition Required", "The server requires the request to be conditional."))
@@ -176,7 +176,7 @@ object StatusCodes extends ObjectRegistry[Int, StatusCode] {
   val ServiceUnavailable            = reg(e(503)("Service Unavailable", "The server is currently unavailable (because it is overloaded or down for maintenance)."))
   val GatewayTimeout                = reg(e(504)("Gateway Timeout", "The server was acting as a gateway or proxy and did not receive a timely response from the upstream server."))
   val HttpVersionNotSupported       = reg(e(505)("HTTP Version Not Supported", "The server does not support the HTTP protocol version used in the request."))
-  @deprecated("deprecated in favor of HttpVersionNotSupported", "10.1.11")
+  @deprecated("deprecated in favor of HttpVersionNotSupported", "Akka HTTP 10.1.11")
   val HTTPVersionNotSupported       = HttpVersionNotSupported
   val VariantAlsoNegotiates         = reg(e(506)("Variant Also Negotiates", "Transparent content negotiation for the request, results in a circular reference."))
   val InsufficientStorage           = reg(e(507)("Insufficient Storage", "Insufficient storage to complete the request."))
diff --git a/http-core/src/main/scala/org/apache/pekko/http/scaladsl/model/headers/HttpCookie.scala b/http-core/src/main/scala/org/apache/pekko/http/scaladsl/model/headers/HttpCookie.scala
index 2746abd82..4d0c817f5 100644
--- a/http-core/src/main/scala/org/apache/pekko/http/scaladsl/model/headers/HttpCookie.scala
+++ b/http-core/src/main/scala/org/apache/pekko/http/scaladsl/model/headers/HttpCookie.scala
@@ -72,7 +72,7 @@ final class HttpCookie private[http] (
     val sameSite: Option[SameSite]) extends jm.headers.HttpCookie with ToStringRenderable with Product with Serializable
     with Equals {
 
-  @deprecated("Please use HttpCookie(name, value).withXxx()", "10.2.0")
+  @deprecated("Please use HttpCookie(name, value).withXxx()", "Akka HTTP 10.2.0")
   def this(
       name: String,
       value: String,
@@ -85,7 +85,7 @@ final class HttpCookie private[http] (
       extension: Option[String] = None) =
     this(name, value, expires, maxAge, domain, path, secure, httpOnly, extension, None)
 
-  @deprecated("for binary compatibility", since = "10.2.0")
+  @deprecated("for binary compatibility", since = "Akka HTTP 10.2.0")
   private[headers] def copy(
       name: String,
       value: String,
@@ -241,7 +241,7 @@ object HttpCookie {
 
   @deprecated(
     "Pattern matching on HttpCookie is deprecated because of the big number of fields and potential future compatibility hazards. Please use other means to check the fields.",
-    since = "10.2.0")
+    since = "Akka HTTP 10.2.0")
   def unapply(cookie: HttpCookie) = Option((
     cookie.name(),
     cookie.value(),
@@ -253,7 +253,7 @@ object HttpCookie {
     cookie.httpOnly(),
     cookie.extension))
 
-  @deprecated("Use HttpCookiePair.toCookie and withXxx methods instead", "10.2.0")
+  @deprecated("Use HttpCookiePair.toCookie and withXxx methods instead", "Akka HTTP 10.2.0")
   def fromPair(
       pair: HttpCookiePair,
       expires: Option[DateTime] = None,
diff --git a/http-core/src/main/scala/org/apache/pekko/http/scaladsl/model/ws/UpgradeToWebSocket.scala b/http-core/src/main/scala/org/apache/pekko/http/scaladsl/model/ws/UpgradeToWebSocket.scala
index 2ebdcf8ff..5b130115b 100644
--- a/http-core/src/main/scala/org/apache/pekko/http/scaladsl/model/ws/UpgradeToWebSocket.scala
+++ b/http-core/src/main/scala/org/apache/pekko/http/scaladsl/model/ws/UpgradeToWebSocket.scala
@@ -18,7 +18,7 @@ import pekko.http.scaladsl.model.HttpResponse
  * enables a request handler to upgrade this connection to a WebSocket connection and
  * registers a WebSocket handler.
  */
-@deprecated("This low-level API has been replaced by an attribute.", since = "10.2.0")
+@deprecated("This low-level API has been replaced by an attribute.", since = "Akka HTTP 10.2.0")
 trait UpgradeToWebSocket extends jm.ws.UpgradeToWebSocket with WebSocketUpgrade {
 
   /**
diff --git a/http-core/src/main/scala/org/apache/pekko/http/scaladsl/settings/ConnectionPoolSettings.scala b/http-core/src/main/scala/org/apache/pekko/http/scaladsl/settings/ConnectionPoolSettings.scala
index 602079fcb..de306dc8d 100644
--- a/http-core/src/main/scala/org/apache/pekko/http/scaladsl/settings/ConnectionPoolSettings.scala
+++ b/http-core/src/main/scala/org/apache/pekko/http/scaladsl/settings/ConnectionPoolSettings.scala
@@ -46,7 +46,7 @@ abstract class ConnectionPoolSettings extends js.ConnectionPoolSettings { self:
   /**
    * The underlying transport used to connect to hosts. By default [[ClientTransport.TCP]] is used.
    */
-  @deprecated("Deprecated in favor of connectionSettings.transport", "10.1.0")
+  @deprecated("Deprecated in favor of connectionSettings.transport", "Akka HTTP 10.1.0")
   def transport: ClientTransport = connectionSettings.transport
 
   /** The time after which the pool will drop an entity automatically if it wasn't read or discarded */
diff --git a/http-core/src/main/scala/org/apache/pekko/http/scaladsl/settings/ParserSettings.scala b/http-core/src/main/scala/org/apache/pekko/http/scaladsl/settings/ParserSettings.scala
index 550012d1b..2ca4a808e 100644
--- a/http-core/src/main/scala/org/apache/pekko/http/scaladsl/settings/ParserSettings.scala
+++ b/http-core/src/main/scala/org/apache/pekko/http/scaladsl/settings/ParserSettings.scala
@@ -227,9 +227,9 @@ object ParserSettings extends SettingsCompanion[ParserSettings] {
       }
   }
 
-  @deprecated("Use forServer or forClient instead", "10.2.0")
+  @deprecated("Use forServer or forClient instead", "Akka HTTP 10.2.0")
   override def apply(config: Config): ParserSettings = ParserSettingsImpl(config)
-  @deprecated("Use forServer or forClient instead", "10.2.0")
+  @deprecated("Use forServer or forClient instead", "Akka HTTP 10.2.0")
   override def apply(configOverrides: String): ParserSettings = ParserSettingsImpl(configOverrides)
 
   def forServer(implicit system: ClassicActorSystemProvider): ParserSettings =
diff --git a/http-core/src/main/scala/org/apache/pekko/http/scaladsl/settings/ServerSettings.scala b/http-core/src/main/scala/org/apache/pekko/http/scaladsl/settings/ServerSettings.scala
index 2fda1dbd9..80da6f027 100644
--- a/http-core/src/main/scala/org/apache/pekko/http/scaladsl/settings/ServerSettings.scala
+++ b/http-core/src/main/scala/org/apache/pekko/http/scaladsl/settings/ServerSettings.scala
@@ -37,7 +37,7 @@ abstract class ServerSettings private[pekko] () extends pekko.http.javadsl.setti
   def timeouts: ServerSettings.Timeouts
   def maxConnections: Int
   def pipeliningLimit: Int
-  @deprecated("use remote-address-attribute instead", since = "10.2.0")
+  @deprecated("use remote-address-attribute instead", since = "Akka HTTP 10.2.0")
   def remoteAddressHeader: Boolean
   def remoteAddressAttribute: Boolean
   def rawRequestUriHeader: Boolean
@@ -48,7 +48,7 @@ abstract class ServerSettings private[pekko] () extends pekko.http.javadsl.setti
   def socketOptions: immutable.Seq[SocketOption]
   def defaultHostHeader: Host
   @Deprecated @deprecated("Kept for binary compatibility; Use websocketSettings.randomFactory instead",
-    since = "10.1.1")
+    since = "Akka HTTP 10.1.1")
   def websocketRandomFactory: () => Random
   def websocketSettings: WebSocketSettings
   def parserSettings: ParserSettings
@@ -79,7 +79,7 @@ abstract class ServerSettings private[pekko] () extends pekko.http.javadsl.setti
   override def getRemoteAddressAttribute: Boolean = remoteAddressAttribute
   override def getLogUnencryptedNetworkBytes = OptionConverters.toJava(logUnencryptedNetworkBytes)
   @Deprecated @deprecated("Kept for binary compatibility; Use websocketSettings.getRandomFactory instead",
-    since = "10.2.0")
+    since = "Akka HTTP 10.2.0")
   override def getWebsocketRandomFactory = new Supplier[Random] {
     override def get(): Random = websocketRandomFactory()
   }
@@ -108,7 +108,7 @@ abstract class ServerSettings private[pekko] () extends pekko.http.javadsl.setti
   override def withSocketOptions(newValue: java.lang.Iterable[SocketOption]): ServerSettings =
     self.copy(socketOptions = newValue.asScala.toList)
   @Deprecated @deprecated("Kept for binary compatibility; Use websocketSettings.withRandomFactoryFactory instead",
-    since = "10.2.0")
+    since = "Akka HTTP 10.2.0")
   override def withWebsocketRandomFactory(newValue: java.util.function.Supplier[Random]): ServerSettings =
     self.copy(websocketSettings = websocketSettings.withRandomFactoryFactory(new Supplier[Random] {
       override def get(): Random = newValue.get()
@@ -131,7 +131,7 @@ abstract class ServerSettings private[pekko] () extends pekko.http.javadsl.setti
   def withDefaultHostHeader(newValue: Host): ServerSettings = self.copy(defaultHostHeader = newValue)
   def withParserSettings(newValue: ParserSettings): ServerSettings = self.copy(parserSettings = newValue)
   @Deprecated @deprecated("Kept for binary compatibility; Use websocketSettings.withRandomFactoryFactory instead",
-    since = "10.2.0")
+    since = "Akka HTTP 10.2.0")
   def withWebsocketRandomFactory(newValue: () => Random): ServerSettings =
     self.copy(websocketSettings = websocketSettings.withRandomFactoryFactory(new Supplier[Random] {
       override def get(): Random = newValue()
diff --git a/http/src/main/java/org/apache/pekko/http/javadsl/coding/Coder.java b/http/src/main/java/org/apache/pekko/http/javadsl/coding/Coder.java
index 5efcfad8c..537029932 100644
--- a/http/src/main/java/org/apache/pekko/http/javadsl/coding/Coder.java
+++ b/http/src/main/java/org/apache/pekko/http/javadsl/coding/Coder.java
@@ -40,7 +40,7 @@ public enum Coder {
     }
 
     /**
-     * @deprecated Synchronous encoding is deprecated since 10.2.0
+     * @deprecated Synchronous encoding is deprecated since Akka HTTP 10.2.0
      */
     @Deprecated
     public ByteString encode(ByteString input) {
diff --git a/http/src/main/java/org/apache/pekko/http/javadsl/server/HttpApp.java b/http/src/main/java/org/apache/pekko/http/javadsl/server/HttpApp.java
index 52bf86d2f..7a9c9b595 100644
--- a/http/src/main/java/org/apache/pekko/http/javadsl/server/HttpApp.java
+++ b/http/src/main/java/org/apache/pekko/http/javadsl/server/HttpApp.java
@@ -27,7 +27,7 @@ import java.util.concurrent.atomic.AtomicReference;
  * Bootstrap trait for Http Server. It helps booting up an akka-http server by only defining the desired routes.
  * It offers additional hooks to modify the default behavior.
  *
- * @deprecated HttpApp this doesn't reflect the latest Akka APIs, since 10.2.0
+ * @deprecated HttpApp this doesn't reflect the latest Pekko APIs, since Akka HTTP 10.2.0
  */
 @Deprecated
 public abstract class HttpApp extends AllDirectives {
diff --git a/http/src/main/scala/org/apache/pekko/http/impl/settings/RoutingSettingsImpl.scala b/http/src/main/scala/org/apache/pekko/http/impl/settings/RoutingSettingsImpl.scala
index 9f620ca94..abfb82fad 100644
--- a/http/src/main/scala/org/apache/pekko/http/impl/settings/RoutingSettingsImpl.scala
+++ b/http/src/main/scala/org/apache/pekko/http/impl/settings/RoutingSettingsImpl.scala
@@ -22,7 +22,7 @@ private[http] final case class RoutingSettingsImpl(
 
   @deprecated(
     "binary compatibility method. Use `akka.stream.materializer.blocking-io-dispatcher` to configure the dispatcher",
-    since = "10.1.6")
+    since = "Akka HTTP 10.1.6")
   override def fileIODispatcher: String = ""
 
   override def productPrefix = "RoutingSettings"
diff --git a/http/src/main/scala/org/apache/pekko/http/javadsl/server/directives/RouteDirectives.scala b/http/src/main/scala/org/apache/pekko/http/javadsl/server/directives/RouteDirectives.scala
index ec4961e1c..6fe445402 100644
--- a/http/src/main/scala/org/apache/pekko/http/javadsl/server/directives/RouteDirectives.scala
+++ b/http/src/main/scala/org/apache/pekko/http/javadsl/server/directives/RouteDirectives.scala
@@ -44,7 +44,7 @@ abstract class RouteDirectives extends RespondWithDirectives {
    * @deprecated Use the `RouteDirectives.concat` method instead.
    */
   @Deprecated
-  @deprecated("Use the RouteDirectives.concat method instead.", "10.1.6")
+  @deprecated("Use the RouteDirectives.concat method instead.", "Akka HTTP 10.1.6")
   @CorrespondsTo("concat")
   @varargs def route(alternatives: Route*): Route = RouteAdapter {
     import pekko.http.scaladsl.server.Directives._
diff --git a/http/src/main/scala/org/apache/pekko/http/javadsl/settings/RoutingSettings.scala b/http/src/main/scala/org/apache/pekko/http/javadsl/settings/RoutingSettings.scala
index 75bea128e..1f9f8afc1 100644
--- a/http/src/main/scala/org/apache/pekko/http/javadsl/settings/RoutingSettings.scala
+++ b/http/src/main/scala/org/apache/pekko/http/javadsl/settings/RoutingSettings.scala
@@ -23,7 +23,7 @@ abstract class RoutingSettings private[pekko] () { self: RoutingSettingsImpl =>
   def getDecodeMaxBytesPerChunk: Int
   @deprecated(
     "binary compatibility method. Use `akka.stream.materializer.blocking-io-dispatcher` to configure the dispatcher",
-    since = "10.1.6")
+    since = "Akka HTTP 10.1.6")
   @Deprecated
   def getFileIODispatcher: String
 
@@ -41,7 +41,7 @@ abstract class RoutingSettings private[pekko] () { self: RoutingSettingsImpl =>
   def withDecodeMaxSize(decodeMaxSize: Long): RoutingSettings = self.copy(decodeMaxSize = decodeMaxSize)
   @deprecated(
     "binary compatibility method. Use `akka.stream.materializer.blocking-io-dispatcher` to configure the dispatcher",
-    since = "10.1.6")
+    since = "Akka HTTP 10.1.6")
   @Deprecated
   def withFileIODispatcher(fileIODispatcher: String): RoutingSettings = self
 }
diff --git a/http/src/main/scala/org/apache/pekko/http/javadsl/unmarshalling/sse/EventStreamUnmarshalling.scala b/http/src/main/scala/org/apache/pekko/http/javadsl/unmarshalling/sse/EventStreamUnmarshalling.scala
index 91cb54e75..b7baa34f5 100644
--- a/http/src/main/scala/org/apache/pekko/http/javadsl/unmarshalling/sse/EventStreamUnmarshalling.scala
+++ b/http/src/main/scala/org/apache/pekko/http/javadsl/unmarshalling/sse/EventStreamUnmarshalling.scala
@@ -38,10 +38,10 @@ object EventStreamUnmarshalling {
   def fromEventsStream(settings: ServerSentEventSettings): Unmarshaller[HttpEntity, Source[ServerSentEvent, NotUsed]] =
     asHttpEntityUnmarshaller(pekko.http.scaladsl.unmarshalling.sse.EventStreamUnmarshalling.fromEventsStream(settings))
 
-  // for binary-compatibility, since 10.1.7
+  // for binary-compatibility, since Akka HTTP 10.1.7
   @deprecated(
     "Binary compatibility method. Invocations should have an implicit ActorSystem in scope to provide access to configuration",
-    "10.1.8")
+    "Akka HTTP 10.1.8")
   val fromEventStream: Unmarshaller[HttpEntity, Source[ServerSentEvent, NotUsed]] =
     asHttpEntityUnmarshaller(pekko.http.scaladsl.unmarshalling.sse.EventStreamUnmarshalling.fromEventStream)
 
diff --git a/http/src/main/scala/org/apache/pekko/http/scaladsl/coding/Decoder.scala b/http/src/main/scala/org/apache/pekko/http/scaladsl/coding/Decoder.scala
index 3b1a21acb..fce69610c 100644
--- a/http/src/main/scala/org/apache/pekko/http/scaladsl/coding/Decoder.scala
+++ b/http/src/main/scala/org/apache/pekko/http/scaladsl/coding/Decoder.scala
@@ -45,7 +45,7 @@ object Decoder {
  * A decoder that is implemented in terms of a [[Stage]]
  */
 @InternalApi
-@deprecated("StreamDecoder is internal API and will be moved or removed in the future", since = "10.2.0")
+@deprecated("StreamDecoder is internal API and will be moved or removed in the future", since = "Akka HTTP 10.2.0")
 trait StreamDecoder extends Decoder { outer =>
   protected def newDecompressorStage(maxBytesPerChunk: Int): () => GraphStage[FlowShape[ByteString, ByteString]]
 
diff --git a/http/src/main/scala/org/apache/pekko/http/scaladsl/coding/Deflate.scala b/http/src/main/scala/org/apache/pekko/http/scaladsl/coding/Deflate.scala
index 7f4218a5c..09ea5c0ec 100644
--- a/http/src/main/scala/org/apache/pekko/http/scaladsl/coding/Deflate.scala
+++ b/http/src/main/scala/org/apache/pekko/http/scaladsl/coding/Deflate.scala
@@ -10,7 +10,7 @@ import pekko.http.scaladsl.model._
 import pekko.http.scaladsl.model.headers.HttpEncodings
 
 @InternalApi
-@deprecated("Actual implementation of Deflate is internal API, use Coders.Deflate instead", since = "10.2.0")
+@deprecated("Actual implementation of Deflate is internal API, use Coders.Deflate instead", since = "Akka HTTP 10.2.0")
 class Deflate private[http] (compressionLevel: Int, val messageFilter: HttpMessage => Boolean) extends Coder
     with StreamDecoder {
   def this(messageFilter: HttpMessage => Boolean) = {
@@ -21,9 +21,9 @@ class Deflate private[http] (compressionLevel: Int, val messageFilter: HttpMessa
   def newCompressor = new DeflateCompressor(compressionLevel)
   def newDecompressorStage(maxBytesPerChunk: Int) = () => new DeflateDecompressor(maxBytesPerChunk)
 
-  @deprecated("Use Coders.Deflate(compressionLevel = ...) instead", since = "10.2.0")
+  @deprecated("Use Coders.Deflate(compressionLevel = ...) instead", since = "Akka HTTP 10.2.0")
   def withLevel(level: Int): Deflate = new Deflate(level, messageFilter)
 }
 @InternalApi
-@deprecated("Actual implementation of Deflate is internal API, use Coders.Deflate instead", since = "10.2.0")
+@deprecated("Actual implementation of Deflate is internal API, use Coders.Deflate instead", since = "Akka HTTP 10.2.0")
 object Deflate extends Deflate(Encoder.DefaultFilter)
diff --git a/http/src/main/scala/org/apache/pekko/http/scaladsl/coding/DeflateCompressor.scala b/http/src/main/scala/org/apache/pekko/http/scaladsl/coding/DeflateCompressor.scala
index ab5915bac..72fe9a6fe 100644
--- a/http/src/main/scala/org/apache/pekko/http/scaladsl/coding/DeflateCompressor.scala
+++ b/http/src/main/scala/org/apache/pekko/http/scaladsl/coding/DeflateCompressor.scala
@@ -17,7 +17,7 @@ import scala.annotation.tailrec
 
 /** Internal API */
 @InternalApi
-@deprecated("DeflateCompressor is internal API and will be moved or removed in the future", since = "10.2.0")
+@deprecated("DeflateCompressor is internal API and will be moved or removed in the future", since = "Akka HTTP 10.2.0")
 class DeflateCompressor private[coding] (compressionLevel: Int) extends Compressor {
   require(compressionLevel >= 0 && compressionLevel <= 9, "Compression level needs to be between 0 and 9")
   import DeflateCompressor._
diff --git a/http/src/main/scala/org/apache/pekko/http/scaladsl/coding/Encoder.scala b/http/src/main/scala/org/apache/pekko/http/scaladsl/coding/Encoder.scala
index 9879cd8ab..6a6b340bd 100644
--- a/http/src/main/scala/org/apache/pekko/http/scaladsl/coding/Encoder.scala
+++ b/http/src/main/scala/org/apache/pekko/http/scaladsl/coding/Encoder.scala
@@ -40,18 +40,18 @@ trait Encoder {
   @InternalApi
   @deprecated(
     "synchronous compression with `encode` is not supported in the future any more, use `encodeAsync` instead",
-    since = "10.2.0")
+    since = "Akka HTTP 10.2.0")
   def encode(input: ByteString): ByteString = newCompressor.compressAndFinish(input)
 
   def encodeAsync(input: ByteString)(implicit mat: Materializer): Future[ByteString] =
     Source.single(input).via(singleUseEncoderFlow()).runWith(Sink.fold(ByteString.empty)(_ ++ _))
 
   @InternalApi
-  @deprecated("newCompressor is internal API", since = "10.2.0")
+  @deprecated("newCompressor is internal API", since = "Akka HTTP 10.2.0")
   def newCompressor: Compressor
 
   @InternalApi
-  @deprecated("newEncodeTransformer is internal API", since = "10.2.0")
+  @deprecated("newEncodeTransformer is internal API", since = "Akka HTTP 10.2.0")
   def newEncodeTransformer(): GraphStage[FlowShape[ByteString, ByteString]] = singleUseEncoderFlow()
 
   private def singleUseEncoderFlow(): GraphStage[FlowShape[ByteString, ByteString]] = {
@@ -78,7 +78,7 @@ object Encoder {
 
 /** A stateful object representing ongoing compression. */
 @InternalApi
-@deprecated("Compressor is internal API and will be moved or removed in the future.", since = "10.2.0")
+@deprecated("Compressor is internal API and will be moved or removed in the future.", since = "Akka HTTP 10.2.0")
 abstract class Compressor {
 
   /**
diff --git a/http/src/main/scala/org/apache/pekko/http/scaladsl/coding/Gzip.scala b/http/src/main/scala/org/apache/pekko/http/scaladsl/coding/Gzip.scala
index aeaea72b3..33f5ce749 100644
--- a/http/src/main/scala/org/apache/pekko/http/scaladsl/coding/Gzip.scala
+++ b/http/src/main/scala/org/apache/pekko/http/scaladsl/coding/Gzip.scala
@@ -10,7 +10,7 @@ import pekko.http.scaladsl.model._
 import pekko.http.scaladsl.model.headers.HttpEncodings
 
 @InternalApi
-@deprecated("Actual implementation of Gzip is internal, use Coders.Gzip instead", since = "10.2.0")
+@deprecated("Actual implementation of Gzip is internal, use Coders.Gzip instead", since = "Akka HTTP 10.2.0")
 class Gzip private[http] (compressionLevel: Int, val messageFilter: HttpMessage => Boolean) extends Coder
     with StreamDecoder {
   def this(messageFilter: HttpMessage => Boolean) = {
@@ -21,7 +21,7 @@ class Gzip private[http] (compressionLevel: Int, val messageFilter: HttpMessage
   def newCompressor = new GzipCompressor(compressionLevel)
   def newDecompressorStage(maxBytesPerChunk: Int) = () => new GzipDecompressor(maxBytesPerChunk)
 
-  @deprecated("Use Coders.Gzip(compressionLevel = ...) instead", since = "10.2.0")
+  @deprecated("Use Coders.Gzip(compressionLevel = ...) instead", since = "Akka HTTP 10.2.0")
   def withLevel(level: Int): Gzip = new Gzip(level, messageFilter)
 }
 
@@ -29,7 +29,7 @@ class Gzip private[http] (compressionLevel: Int, val messageFilter: HttpMessage
  * An encoder and decoder for the HTTP 'gzip' encoding.
  */
 @InternalApi
-@deprecated("Actual implementation of Gzip is internal API, use Coders.Gzip instead", since = "10.2.0")
+@deprecated("Actual implementation of Gzip is internal API, use Coders.Gzip instead", since = "Akka HTTP 10.2.0")
 object Gzip extends Gzip(Encoder.DefaultFilter) {
   def apply(messageFilter: HttpMessage => Boolean) = new Gzip(messageFilter)
 }
diff --git a/http/src/main/scala/org/apache/pekko/http/scaladsl/coding/NoCoding.scala b/http/src/main/scala/org/apache/pekko/http/scaladsl/coding/NoCoding.scala
index 40ed08ebd..8b05ad94b 100644
--- a/http/src/main/scala/org/apache/pekko/http/scaladsl/coding/NoCoding.scala
+++ b/http/src/main/scala/org/apache/pekko/http/scaladsl/coding/NoCoding.scala
@@ -17,7 +17,8 @@ import headers.HttpEncodings
  * An encoder and decoder for the HTTP 'identity' encoding.
  */
 @InternalApi
-@deprecated("Actual implementation of NoCoding is internal API, use Coders.NoCoding instead", since = "10.2.0")
+@deprecated("Actual implementation of NoCoding is internal API, use Coders.NoCoding instead",
+  since = "Akka HTTP 10.2.0")
 object NoCoding extends Coder with StreamDecoder {
   val encoding = HttpEncodings.identity
 
@@ -34,7 +35,7 @@ object NoCoding extends Coder with StreamDecoder {
 
 /** Internal API */
 @InternalApi
-@deprecated("NoCodingCompressor is internal API and will be moved or removed in the future", since = "10.2.0")
+@deprecated("NoCodingCompressor is internal API and will be moved or removed in the future", since = "Akka HTTP 10.2.0")
 object NoCodingCompressor extends Compressor {
   def compress(input: ByteString): ByteString = input
   def flush() = ByteString.empty
diff --git a/http/src/main/scala/org/apache/pekko/http/scaladsl/server/HttpApp.scala b/http/src/main/scala/org/apache/pekko/http/scaladsl/server/HttpApp.scala
index d6003b6dc..b294f5245 100644
--- a/http/src/main/scala/org/apache/pekko/http/scaladsl/server/HttpApp.scala
+++ b/http/src/main/scala/org/apache/pekko/http/scaladsl/server/HttpApp.scala
@@ -26,7 +26,7 @@ import scala.util.{ Failure, Success, Try }
  * Bootstrap trait for Http Server. It helps booting up an akka-http server by only defining the desired routes.
  * It offers additional hooks to modify the default behavior.
  */
-@deprecated("HttpApp this doesn't reflect the latest Akka APIs", "10.2.0")
+@deprecated("HttpApp this doesn't reflect the latest Akka APIs", "Akka HTTP 10.2.0")
 abstract class HttpApp extends Directives {
 
   private val serverBinding = new AtomicReference[ServerBinding]()
diff --git a/http/src/main/scala/org/apache/pekko/http/scaladsl/server/Rejection.scala b/http/src/main/scala/org/apache/pekko/http/scaladsl/server/Rejection.scala
index 5a0c75d41..f07d6819b 100644
--- a/http/src/main/scala/org/apache/pekko/http/scaladsl/server/Rejection.scala
+++ b/http/src/main/scala/org/apache/pekko/http/scaladsl/server/Rejection.scala
@@ -129,18 +129,18 @@ final class UnsupportedRequestContentTypeRejection(
   override def getSupported: java.util.Set[model.ContentTypeRange] =
     scala.collection.mutable.Set(supported.map(_.asJava).toVector: _*).asJava // TODO optimise
 
-  @deprecated("for binary compatibility", since = "10.1.9")
+  @deprecated("for binary compatibility", since = "Akka HTTP 10.1.9")
   def this(supported: Set[ContentTypeRange]) = this(supported, None)
 
-  @deprecated("for binary compatibility", since = "10.1.9")
+  @deprecated("for binary compatibility", since = "Akka HTTP 10.1.9")
   def copy(supported: Set[ContentTypeRange]) =
     new UnsupportedRequestContentTypeRejection(supported, this.contentType)
 
-  @deprecated("for binary compatibility", since = "10.1.9")
+  @deprecated("for binary compatibility", since = "Akka HTTP 10.1.9")
   def copy$default$1(supported: Set[ContentTypeRange]) =
     new UnsupportedRequestContentTypeRejection(supported, this.contentType)
 
-  @deprecated("for binary compatibility", since = "10.1.9")
+  @deprecated("for binary compatibility", since = "Akka HTTP 10.1.9")
   def copy(
       supported: Set[ContentTypeRange] = this.supported,
       contentType: Option[ContentType] = this.contentType) =
@@ -165,7 +165,7 @@ object UnsupportedRequestContentTypeRejection
       supported: Set[ContentTypeRange], contentType: Option[ContentType]): UnsupportedRequestContentTypeRejection =
     new UnsupportedRequestContentTypeRejection(supported, contentType)
 
-  @deprecated("for binary compatibility", since = "10.1.9")
+  @deprecated("for binary compatibility", since = "Akka HTTP 10.1.9")
   def apply(supported: Set[ContentTypeRange]): UnsupportedRequestContentTypeRejection =
     new UnsupportedRequestContentTypeRejection(supported, None)
 
diff --git a/http/src/main/scala/org/apache/pekko/http/scaladsl/server/Route.scala b/http/src/main/scala/org/apache/pekko/http/scaladsl/server/Route.scala
index a487eed1f..217215285 100644
--- a/http/src/main/scala/org/apache/pekko/http/scaladsl/server/Route.scala
+++ b/http/src/main/scala/org/apache/pekko/http/scaladsl/server/Route.scala
@@ -37,7 +37,7 @@ object Route {
   def seal(route: Route)(implicit
       routingSettings: RoutingSettings = null,
       @deprecated("For binary compatibility. parserSettings is never used",
-        since = "10.1.8") parserSettings: ParserSettings = null,
+        since = "Akka HTTP 10.1.8") parserSettings: ParserSettings = null,
       rejectionHandler: RejectionHandler = RejectionHandler.default,
       exceptionHandler: ExceptionHandler = null): Route = {
     import directives.ExecutionDirectives._
@@ -64,7 +64,7 @@ object Route {
   /**
    * Turns a `Route` into a server flow.
    */
-  @deprecated("Replaced by `toFlow` that takes an implicit ActorSystem.", "10.2.0")
+  @deprecated("Replaced by `toFlow` that takes an implicit ActorSystem.", "Akka HTTP 10.2.0")
   def handlerFlow(route: Route)(implicit
       routingSettings: RoutingSettings,
       parserSettings: ParserSettings,
@@ -96,7 +96,7 @@ object Route {
    */
   @deprecated(
     "Use `toFunction` instead, which only requires an implicit ActorSystem and no rejection/exception handlers. Use directives to specify custom exceptions or rejection handlers",
-    "10.2.0")
+    "Akka HTTP 10.2.0")
   def asyncHandler(route: Route)(implicit
       routingSettings: RoutingSettings,
       parserSettings: ParserSettings,
diff --git a/http/src/main/scala/org/apache/pekko/http/scaladsl/server/RouteResult.scala b/http/src/main/scala/org/apache/pekko/http/scaladsl/server/RouteResult.scala
index 95d5b5d3d..d46e2a51d 100644
--- a/http/src/main/scala/org/apache/pekko/http/scaladsl/server/RouteResult.scala
+++ b/http/src/main/scala/org/apache/pekko/http/scaladsl/server/RouteResult.scala
@@ -57,7 +57,7 @@ object RouteResult extends LowerPriorityRouteResultImplicits {
       implicit system: ClassicActorSystemProvider): HttpRequest => Future[HttpResponse] =
     Route.toFunction(route)
 
-  @deprecated("Replaced by routeToFlow", "10.2.0")
+  @deprecated("Replaced by routeToFlow", "Akka HTTP 10.2.0")
   def route2HandlerFlow(route: Route)(
       implicit
       routingSettings: RoutingSettings,
@@ -86,7 +86,7 @@ sealed abstract class LowerPriorityRouteResultImplicits {
    * is in that type means this implicit conversion come into scope whereever
    * a `Route` is given but a `Flow` is expected.
    */
-  @deprecated("make an ActorSystem available implicitly instead", "10.2.0")
+  @deprecated("make an ActorSystem available implicitly instead", "Akka HTTP 10.2.0")
   implicit def routeToFlowViaMaterializer(route: Route)(
       implicit materializer: Materializer): Flow[HttpRequest, HttpResponse, NotUsed] =
     Route.toFlow(route)(ActorMaterializerHelper.downcast(materializer).system)
diff --git a/http/src/main/scala/org/apache/pekko/http/scaladsl/server/directives/FormFieldDirectives.scala b/http/src/main/scala/org/apache/pekko/http/scaladsl/server/directives/FormFieldDirectives.scala
index 725df2acd..49d94e485 100644
--- a/http/src/main/scala/org/apache/pekko/http/scaladsl/server/directives/FormFieldDirectives.scala
+++ b/http/src/main/scala/org/apache/pekko/http/scaladsl/server/directives/FormFieldDirectives.scala
@@ -56,7 +56,8 @@ trait FormFieldDirectives extends FormFieldDirectivesInstances with ToNameRecept
    * @group form
    */
   @pre213
-  @deprecated("Use new `formField` overloads with FieldSpec parameters. Kept for binary compatibility", "10.2.0")
+  @deprecated("Use new `formField` overloads with FieldSpec parameters. Kept for binary compatibility",
+    "Akka HTTP 10.2.0")
   private[http] def formField(pdm: FieldMagnet): pdm.Out = formFields(pdm)
 
   /**
@@ -66,7 +67,8 @@ trait FormFieldDirectives extends FormFieldDirectivesInstances with ToNameRecept
    * @group form
    */
   @since213
-  @deprecated("Use new `formField` overloads with FieldSpec parameters. Kept for binary compatibility", "10.2.0")
+  @deprecated("Use new `formField` overloads with FieldSpec parameters. Kept for binary compatibility",
+    "Akka HTTP 10.2.0")
   private[http] def formField(pdm: FieldMagnet): Directive[pdm.U] = formFields(pdm)
 
   /**
@@ -76,7 +78,8 @@ trait FormFieldDirectives extends FormFieldDirectivesInstances with ToNameRecept
    * @group form
    */
   @pre213
-  @deprecated("Use new `formField` overloads with FieldSpec parameters. Kept for binary compatibility", "10.2.0")
+  @deprecated("Use new `formField` overloads with FieldSpec parameters. Kept for binary compatibility",
+    "Akka HTTP 10.2.0")
   private[http] def formFields(pdm: FieldMagnet): pdm.Out =
     pdm.convert(toStrictEntity(StrictForm.toStrictTimeout).wrap { pdm() })
 
@@ -87,7 +90,8 @@ trait FormFieldDirectives extends FormFieldDirectivesInstances with ToNameRecept
    * @group form
    */
   @since213
-  @deprecated("Use new `formField` overloads with FieldSpec parameters. Kept for binary compatibility", "10.2.0")
+  @deprecated("Use new `formField` overloads with FieldSpec parameters. Kept for binary compatibility",
+    "Akka HTTP 10.2.0")
   private[http] def formFields(pdm: FieldMagnet): Directive[pdm.U] =
     toStrictEntity(StrictForm.toStrictTimeout).wrap { pdm() }
 }
@@ -191,7 +195,7 @@ object FormFieldDirectives extends FormFieldDirectives {
   }
 
   @deprecated("Use new `formField` overloads with FieldSpec parameters. Kept for binary compatibility",
-    since = "10.2.0")
+    since = "Akka HTTP 10.2.0")
   sealed trait FieldMagnet {
     type U
     def apply(): Directive[U]
@@ -205,7 +209,7 @@ object FormFieldDirectives extends FormFieldDirectives {
   }
 
   @deprecated("Use new `formField` overloads with FieldSpec parameters. Kept for binary compatibility",
-    since = "10.2.0")
+    since = "Akka HTTP 10.2.0")
   object FieldMagnet {
     implicit def apply[T](value: T)(
         implicit fdef: FieldDef[T]): FieldMagnet { type U = fdef.U; type Out = Directive[fdef.U] } =
@@ -219,17 +223,17 @@ object FormFieldDirectives extends FormFieldDirectives {
   }
 
   @deprecated("Use new `formFields` overloads with FieldSpec parameters. Kept for binary compatibility",
-    since = "10.2.0")
+    since = "Akka HTTP 10.2.0")
   type FieldDefAux[A, B] = FieldDef[A] { type U = B }
 
   @deprecated("Use new `formFields` overloads with FieldSpec parameters. Kept for binary compatibility",
-    since = "10.2.0")
+    since = "Akka HTTP 10.2.0")
   sealed trait FieldDef[T] {
     type U
     def apply(value: T): Directive[U]
   }
   @deprecated("Use new `formFields` overloads with FieldSpec parameters. Kept for binary compatibility",
-    since = "10.2.0")
+    since = "Akka HTTP 10.2.0")
   object FieldDef {
     protected def fieldDef[A, B](f: A => Directive[B]): FieldDefAux[A, B] =
       new FieldDef[A] {
diff --git a/http/src/main/scala/org/apache/pekko/http/scaladsl/server/directives/HeaderDirectives.scala b/http/src/main/scala/org/apache/pekko/http/scaladsl/server/directives/HeaderDirectives.scala
index 4db531736..6aa1a8de0 100644
--- a/http/src/main/scala/org/apache/pekko/http/scaladsl/server/directives/HeaderDirectives.scala
+++ b/http/src/main/scala/org/apache/pekko/http/scaladsl/server/directives/HeaderDirectives.scala
@@ -73,7 +73,7 @@ trait HeaderDirectives {
    */
   @deprecated(
     "Use string argument version or `headerValueByType`, e.g. instead of `headerValueByName('Referer)` use `headerValueByType(Referer)`",
-    since = "10.2.0")
+    since = "Akka HTTP 10.2.0")
   def headerValueByName(headerName: Symbol): Directive1[String] = headerValueByName(headerName.name)
 
   /**
@@ -128,7 +128,7 @@ trait HeaderDirectives {
    */
   @deprecated(
     "Use string argument version or `headerValueByType`, e.g. instead of `optionalHeaderValueByName('Referer)` use `optionalHeaderValueByType(Referer)`",
-    since = "10.2.0")
+    since = "Akka HTTP 10.2.0")
   def optionalHeaderValueByName(headerName: Symbol): Directive1[Option[String]] =
     optionalHeaderValueByName(headerName.name)
 
@@ -186,7 +186,7 @@ object HeaderMagnet extends LowPriorityHeaderMagnetImplicits {
 
   @deprecated(
     "Pass the companion object to headerValueByType as a parameter instead, e.g. `headerValueByType(Origin)` instead of `headerValueByType[Origin](())`",
-    since = "10.2.0")
+    since = "Akka HTTP 10.2.0")
   implicit def fromUnitForModeledCustomHeader[T <: ModeledCustomHeader[T], H <: ModeledCustomHeaderCompanion[T]](
       u: Unit)(implicit tag: ClassTag[T], companion: ModeledCustomHeaderCompanion[T]): HeaderMagnet[T] =
     fromClassTagForModeledCustomHeader[T, H](tag, companion)
@@ -228,7 +228,7 @@ trait LowPriorityHeaderMagnetImplicits {
 
   @deprecated(
     "Pass the companion object to headerValueByType as a parameter instead, e.g. `headerValueByType(Origin)` instead of `headerValueByType[Origin](())`",
-    since = "10.2.0")
+    since = "Akka HTTP 10.2.0")
   implicit def fromUnitNormalHeader[T <: HttpHeader](u: Unit)(implicit tag: ClassTag[T]): HeaderMagnet[T] =
     fromClassTagNormalHeader(tag)
 
diff --git a/http/src/main/scala/org/apache/pekko/http/scaladsl/server/directives/ParameterDirectives.scala b/http/src/main/scala/org/apache/pekko/http/scaladsl/server/directives/ParameterDirectives.scala
index 086d887d4..06ffc5850 100644
--- a/http/src/main/scala/org/apache/pekko/http/scaladsl/server/directives/ParameterDirectives.scala
+++ b/http/src/main/scala/org/apache/pekko/http/scaladsl/server/directives/ParameterDirectives.scala
@@ -46,7 +46,8 @@ trait ParameterDirectives extends ParameterDirectivesInstances with ToNameRecept
    *
    * @group param
    */
-  @deprecated("Use new `parameters` overloads with ParamSpec parameters. Kept for binary compatibility", "10.2.0")
+  @deprecated("Use new `parameters` overloads with ParamSpec parameters. Kept for binary compatibility",
+    "Akka HTTP 10.2.0")
   private[http] def parameter(pdm: ParamMagnet): pdm.Out = pdm()
 
   /**
@@ -55,7 +56,8 @@ trait ParameterDirectives extends ParameterDirectivesInstances with ToNameRecept
    *
    * @group param
    */
-  @deprecated("Use new `parameters` overloads with ParamSpec parameters. Kept for binary compatibility", "10.2.0")
+  @deprecated("Use new `parameters` overloads with ParamSpec parameters. Kept for binary compatibility",
+    "Akka HTTP 10.2.0")
   private[http] def parameters(pdm: ParamMagnet): pdm.Out = pdm()
 }
 
@@ -119,12 +121,14 @@ object ParameterDirectives extends ParameterDirectives {
       ParamSpec(requiredFilter(name, fsu, requiredValue).tmap(_ => Tuple1(())))
   }
 
-  @deprecated("Use new `parameters` overloads with ParamSpec parameters. Kept for binary compatibility", "10.2.0")
+  @deprecated("Use new `parameters` overloads with ParamSpec parameters. Kept for binary compatibility",
+    "Akka HTTP 10.2.0")
   sealed trait ParamMagnet {
     type Out
     def apply(): Out
   }
-  @deprecated("Use new `parameters` overloads with ParamSpec parameters. Kept for binary compatibility", "10.2.0")
+  @deprecated("Use new `parameters` overloads with ParamSpec parameters. Kept for binary compatibility",
+    "Akka HTTP 10.2.0")
   object ParamMagnet {
     def apply[T](value: T)(implicit pdef: ParamDef[T]): ParamMagnet { type Out = pdef.Out } =
       new ParamMagnet {
@@ -133,14 +137,17 @@ object ParameterDirectives extends ParameterDirectives {
       }
   }
 
-  @deprecated("Use new `parameters` overloads with ParamSpec parameters. Kept for binary compatibility", "10.2.0")
+  @deprecated("Use new `parameters` overloads with ParamSpec parameters. Kept for binary compatibility",
+    "Akka HTTP 10.2.0")
   type ParamDefAux[T, U] = ParamDef[T] { type Out = U }
-  @deprecated("Use new `parameters` overloads with ParamSpec parameters. Kept for binary compatibility", "10.2.0")
+  @deprecated("Use new `parameters` overloads with ParamSpec parameters. Kept for binary compatibility",
+    "Akka HTTP 10.2.0")
   sealed trait ParamDef[T] {
     type Out
     def apply(value: T): Out
   }
-  @deprecated("Use new `parameters` overloads with ParamSpec parameters. Kept for binary compatibility", "10.2.0")
+  @deprecated("Use new `parameters` overloads with ParamSpec parameters. Kept for binary compatibility",
+    "Akka HTTP 10.2.0")
   object ParamDef {
     import Impl._
     import pekko.http.scaladsl.unmarshalling.{ FromStringUnmarshaller => FSU }
diff --git a/http/src/main/scala/org/apache/pekko/http/scaladsl/server/directives/WebSocketDirectives.scala b/http/src/main/scala/org/apache/pekko/http/scaladsl/server/directives/WebSocketDirectives.scala
index a98e5b84b..4e0686a12 100644
--- a/http/src/main/scala/org/apache/pekko/http/scaladsl/server/directives/WebSocketDirectives.scala
+++ b/http/src/main/scala/org/apache/pekko/http/scaladsl/server/directives/WebSocketDirectives.scala
@@ -27,7 +27,7 @@ trait WebSocketDirectives {
    *
    * @group websocket
    */
-  @deprecated("use `extractWebSocketUpgrade` instead", since = "10.2.0")
+  @deprecated("use `extractWebSocketUpgrade` instead", since = "Akka HTTP 10.2.0")
   def extractUpgradeToWebSocket: Directive1[UpgradeToWebSocket] =
     optionalHeaderValueByType(classOf[UpgradeToWebSocket]).flatMap {
       case Some(upgrade) => provide(upgrade)
diff --git a/http/src/main/scala/org/apache/pekko/http/scaladsl/settings/RoutingSettings.scala b/http/src/main/scala/org/apache/pekko/http/scaladsl/settings/RoutingSettings.scala
index e88875d03..5b11561b3 100644
--- a/http/src/main/scala/org/apache/pekko/http/scaladsl/settings/RoutingSettings.scala
+++ b/http/src/main/scala/org/apache/pekko/http/scaladsl/settings/RoutingSettings.scala
@@ -24,7 +24,7 @@ abstract class RoutingSettings private[pekko] () extends pekko.http.javadsl.sett
   def decodeMaxSize: Long
   @deprecated(
     "binary compatibility method. Use `akka.stream.materializer.blocking-io-dispatcher` to configure the dispatcher",
-    since = "10.1.6")
+    since = "Akka HTTP 10.1.6")
   def fileIODispatcher: String
 
   /* Java APIs */
@@ -37,7 +37,7 @@ abstract class RoutingSettings private[pekko] () extends pekko.http.javadsl.sett
   def getDecodeMaxSize: Long = decodeMaxSize
   @deprecated(
     "binary compatibility method. Use `akka.stream.materializer.blocking-io-dispatcher` to configure the dispatcher",
-    since = "10.1.6")
+    since = "Akka HTTP 10.1.6")
   @Deprecated
   def getFileIODispatcher: String = fileIODispatcher
 
@@ -55,7 +55,7 @@ abstract class RoutingSettings private[pekko] () extends pekko.http.javadsl.sett
   override def withDecodeMaxSize(decodeMaxSize: Long): RoutingSettings = self.copy(decodeMaxSize = decodeMaxSize)
   @deprecated(
     "binary compatibility method. Use `akka.stream.materializer.blocking-io-dispatcher` to configure the dispatcher",
-    since = "10.1.6")
+    since = "Akka HTTP 10.1.6")
   @Deprecated
   override def withFileIODispatcher(fileIODispatcher: String): RoutingSettings = self
 }
diff --git a/http/src/main/scala/org/apache/pekko/http/scaladsl/unmarshalling/Unmarshaller.scala b/http/src/main/scala/org/apache/pekko/http/scaladsl/unmarshalling/Unmarshaller.scala
index 23776a92b..fe3d8aeea 100644
--- a/http/src/main/scala/org/apache/pekko/http/scaladsl/unmarshalling/Unmarshaller.scala
+++ b/http/src/main/scala/org/apache/pekko/http/scaladsl/unmarshalling/Unmarshaller.scala
@@ -160,18 +160,18 @@ object Unmarshaller
       extends RuntimeException(supported.mkString(
         s"Unsupported Content-Type [$actualContentType], supported: ", ", ", "")) with Product with Serializable {
 
-    @deprecated("for binary compatibility", since = "10.1.9")
+    @deprecated("for binary compatibility", since = "Akka HTTP 10.1.9")
     def this(supported: Set[ContentTypeRange]) = this(supported, None)
 
-    @deprecated("for binary compatibility", since = "10.1.9")
+    @deprecated("for binary compatibility", since = "Akka HTTP 10.1.9")
     def copy(supported: Set[ContentTypeRange]): UnsupportedContentTypeException =
       new UnsupportedContentTypeException(supported, this.actualContentType)
 
-    @deprecated("for binary compatibility", since = "10.1.9")
+    @deprecated("for binary compatibility", since = "Akka HTTP 10.1.9")
     def copy$default$1(supported: Set[ContentTypeRange]): UnsupportedContentTypeException =
       new UnsupportedContentTypeException(supported, this.actualContentType)
 
-    @deprecated("for binary compatibility", since = "10.1.9")
+    @deprecated("for binary compatibility", since = "Akka HTTP 10.1.9")
     def copy(
         supported: Set[ContentTypeRange] = this.supported,
         contentType: Option[ContentType] = this.actualContentType): UnsupportedContentTypeException =
diff --git a/http/src/main/scala/org/apache/pekko/http/scaladsl/unmarshalling/sse/EventStreamUnmarshalling.scala b/http/src/main/scala/org/apache/pekko/http/scaladsl/unmarshalling/sse/EventStreamUnmarshalling.scala
index d56802ec2..54b360d11 100644
--- a/http/src/main/scala/org/apache/pekko/http/scaladsl/unmarshalling/sse/EventStreamUnmarshalling.scala
+++ b/http/src/main/scala/org/apache/pekko/http/scaladsl/unmarshalling/sse/EventStreamUnmarshalling.scala
@@ -45,7 +45,7 @@ trait EventStreamUnmarshalling {
    */
   @deprecated(
     "Set this property in configuration as `akka.http.sse.max-line-size` before calling fromEventsStream(implicit ActorSystem)",
-    "10.1.8")
+    "Akka HTTP 10.1.8")
   protected def maxLineSize: Int = 4096
 
   /**
@@ -53,12 +53,12 @@ trait EventStreamUnmarshalling {
    */
   @deprecated(
     "Set this property in configuration as `akka.http.sse.max-event-size` before calling fromEventsStream(implicit ActorSystem)",
-    "10.1.8")
+    "Akka HTTP 10.1.8")
   protected def maxEventSize: Int = 8192
 
   @deprecated(
     "Binary compatibility method. Invocations should have an implicit ActorSystem in scope to provide access to configuration",
-    "10.1.8")
+    "Akka HTTP 10.1.8")
   final val fromEventStream: FromEntityUnmarshaller[Source[ServerSentEvent, NotUsed]] =
     fromEventsStream(maxEventSize, maxLineSize, emitEmptyEvents = false)
 


---------------------------------------------------------------------
To unsubscribe, e-mail: commits-unsubscribe@pekko.apache.org
For additional commands, e-mail: commits-help@pekko.apache.org
diff --git a/http-core/src/main/scala/org/apache/pekko/http/javadsl/Http.scala b/http-core/src/main/scala/org/apache/pekko/http/javadsl/Http.scala
index 602f473fd..18a0fc22c 100644
--- a/http-core/src/main/scala/org/apache/pekko/http/javadsl/Http.scala
+++ b/http-core/src/main/scala/org/apache/pekko/http/javadsl/Http.scala
@@ -109,10 +109,10 @@ class Http(system: ExtendedActorSystem) extends pekko.actor.Extension {
    * The server will be bound using HTTPS if the [[ConnectHttp]] object is configured with an [[HttpsConnectionContext]],
    * or the [[defaultServerHttpContext]] has been configured to be an [[HttpsConnectionContext]].
    *
    * @deprecated since 10.2.0: Use Http.get(system).newServerAt(interface, port).connectionSource() instead
    */
   @Deprecated
-  @deprecated("Use newServerAt instead", since = "10.2.0")
+  @deprecated("Use newServerAt instead", since = "Akka HTTP 10.2.0")
   def bind(connect: ConnectHttp): Source[IncomingConnection, CompletionStage[ServerBinding]] = {
     val connectionContext = connect.effectiveConnectionContext(defaultServerHttpContext).asScala
     new Source(delegate.bind(connect.host, connect.port, connectionContext)
@@ -135,10 +135,10 @@ class Http(system: ExtendedActorSystem) extends pekko.actor.Extension {
    * The server will be bound using HTTPS if the [[ConnectHttp]] object is configured with an [[HttpsConnectionContext]],
    * or the [[defaultServerHttpContext]] has been configured to be an [[HttpsConnectionContext]].
    *
    * @deprecated since 10.2.0: Use Http.get(system).newServerAt(interface, port).withSettings(settings).connectionSource() instead
    */
   @Deprecated
-  @deprecated("Use newServerAt instead", since = "10.2.0")
+  @deprecated("Use newServerAt instead", since = "Akka HTTP 10.2.0")
   def bind(
       connect: ConnectHttp,
       settings: ServerSettings): Source[IncomingConnection, CompletionStage[ServerBinding]] = {
@@ -164,10 +164,10 @@ class Http(system: ExtendedActorSystem) extends pekko.actor.Extension {
    * The server will be bound using HTTPS if the [[ConnectHttp]] object is configured with an [[HttpsConnectionContext]],
    * or the [[defaultServerHttpContext]] has been configured to be an [[HttpsConnectionContext]].
    *
    * @deprecated since 10.2.0: Use Http.get(system).newServerAt(interface, port).withSettings(settings).logTo(log).connectionSource() instead
    */
   @Deprecated
-  @deprecated("Use newServerAt instead", since = "10.2.0")
+  @deprecated("Use newServerAt instead", since = "Akka HTTP 10.2.0")
   def bind(
       connect: ConnectHttp,
       settings: ServerSettings,
@@ -189,10 +189,10 @@ class Http(system: ExtendedActorSystem) extends pekko.actor.Extension {
    * The server will be bound using HTTPS if the [[ConnectHttp]] object is configured with an [[HttpsConnectionContext]],
    * or the [[defaultServerHttpContext]] has been configured to be an [[HttpsConnectionContext]].
    *
    * @deprecated since 10.2.0: Use Http.get(system).newServerAt(interface, port).bindFlow(handler) instead.
    */
   @Deprecated
-  @deprecated("Use newServerAt instead", since = "10.2.0")
+  @deprecated("Use newServerAt instead", since = "Akka HTTP 10.2.0")
   def bindAndHandle(
       handler: Flow[HttpRequest, HttpResponse, _],
       connect: ConnectHttp,
@@ -215,10 +215,10 @@ class Http(system: ExtendedActorSystem) extends pekko.actor.Extension {
    * The server will be bound using HTTPS if the [[ConnectHttp]] object is configured with an [[HttpsConnectionContext]],
    * or the [[defaultServerHttpContext]] has been configured to be an [[HttpsConnectionContext]].
    *
    * @deprecated since 10.2.0: Use Http.get(system).newServerAt(interface, port).withSettings(settings).logTo(log).bindFlow(handler) instead.
    */
   @Deprecated
-  @deprecated("Use newServerAt instead", since = "10.2.0")
+  @deprecated("Use newServerAt instead", since = "Akka HTTP 10.2.0")
   def bindAndHandle(
       handler: Flow[HttpRequest, HttpResponse, _],
       connect: ConnectHttp,
@@ -243,10 +243,10 @@ class Http(system: ExtendedActorSystem) extends pekko.actor.Extension {
    * The server will be bound using HTTPS if the [[ConnectHttp]] object is configured with an [[HttpsConnectionContext]],
    * or the [[defaultServerHttpContext]] has been configured to be an [[HttpsConnectionContext]].
    *
    * @deprecated since 10.2.0: Use Http.get(system).newServerAt(interface, port).bindSync(handler) instead
    */
   @Deprecated
-  @deprecated("Use newServerAt instead", since = "10.2.0")
+  @deprecated("Use newServerAt instead", since = "Akka HTTP 10.2.0")
   def bindAndHandleSync(
       handler: pekko.japi.Function[HttpRequest, HttpResponse],
       connect: ConnectHttp,
@@ -267,10 +267,10 @@ class Http(system: ExtendedActorSystem) extends pekko.actor.Extension {
    * The server will be bound using HTTPS if the [[ConnectHttp]] object is configured with an [[HttpsConnectionContext]],
    * or the [[defaultServerHttpContext]] has been configured to be an [[HttpsConnectionContext]].
    *
    * @deprecated since 10.2.0: Use Http.get(system).newServerAt(interface, port).withSettings(settings).logTo(log).bindSync(handler) instead
    */
   @Deprecated
-  @deprecated("Use newServerAt instead", since = "10.2.0")
+  @deprecated("Use newServerAt instead", since = "Akka HTTP 10.2.0")
   def bindAndHandleSync(
       handler: pekko.japi.Function[HttpRequest, HttpResponse],
       connect: ConnectHttp,
@@ -295,10 +295,10 @@ class Http(system: ExtendedActorSystem) extends pekko.actor.Extension {
    * The server will be bound using HTTPS if the [[ConnectHttp]] object is configured with an [[HttpsConnectionContext]],
    * or the [[defaultServerHttpContext]] has been configured to be an [[HttpsConnectionContext]].
    *
    * @deprecated since 10.2.0: Use Http.get(system).newServerAt(interface, port).bind(handler) instead
    */
   @Deprecated
-  @deprecated("Use newServerAt instead", since = "10.2.0")
+  @deprecated("Use newServerAt instead", since = "Akka HTTP 10.2.0")
   def bindAndHandleAsync(
       handler: pekko.japi.Function[HttpRequest, CompletionStage[HttpResponse]],
       connect: ConnectHttp,
@@ -319,10 +319,10 @@ class Http(system: ExtendedActorSystem) extends pekko.actor.Extension {
    * The server will be bound using HTTPS if the [[ConnectHttp]] object is configured with an [[HttpsConnectionContext]],
    * or the [[defaultServerHttpContext]] has been configured to be an [[HttpsConnectionContext]].
    *
    * @deprecated since 10.2.0: Use Http.get(system).newServerAt(interface, port).withSettings(settings).logTo(log).bind(handler) instead
    */
   @Deprecated
-  @deprecated("Use newServerAt instead", since = "10.2.0")
+  @deprecated("Use newServerAt instead", since = "Akka HTTP 10.2.0")
   def bindAndHandleAsync(
       handler: pekko.japi.Function[HttpRequest, CompletionStage[HttpResponse]],
       connect: ConnectHttp,
@@ -793,9 +793,9 @@ class Http(system: ExtendedActorSystem) extends pekko.actor.Extension {
    * Gets the current default server-side [[ConnectionContext]] – defaults to plain HTTP.
    * Can be modified using [[setDefaultServerHttpContext]], and will then apply for servers bound after that call has completed.
    *
    * @deprecated since 10.2.0: set context explicitly when binding
    */
-  @Deprecated @deprecated("Set context explicitly when binding", since = "10.2.0")
+  @Deprecated @deprecated("Set context explicitly when binding", since = "Akka HTTP 10.2.0")
   def defaultServerHttpContext: ConnectionContext =
     delegate.defaultServerHttpContext
 
@@ -803,9 +803,9 @@ class Http(system: ExtendedActorSystem) extends pekko.actor.Extension {
    * Sets the default server-side [[ConnectionContext]].
    * If it is an instance of [[HttpsConnectionContext]] then the server will be bound using HTTPS.
    *
    * @deprecated since 10.2.0: set context explicitly when binding
    */
-  @Deprecated @deprecated("Set context explicitly when binding", since = "10.2.0")
+  @Deprecated @deprecated("Set context explicitly when binding", since = "Akka HTTP 10.2.0")
   def setDefaultServerHttpContext(context: ConnectionContext): Unit =
     delegate.setDefaultServerHttpContext(context.asScala)
 
@@ -109,10 +109,10 @@ class Http(system: ExtendedActorSystem) extends pekko.actor.Extension {
    * or the [[defaultServerHttpContext]] has been configured to be an [[HttpsConnectionContext]].
    *
-   * @deprecated since 10.2.0: Use Http.get(system).newServerAt(interface, port).connectionSource() instead
+   * @deprecated since Akka HTTP 10.2.0: Use Http.get(system).newServerAt(interface, port).connectionSource() instead
    */
   @Deprecated
@@ -135,10 +135,10 @@ class Http(system: ExtendedActorSystem) extends pekko.actor.Extension {
    * or the [[defaultServerHttpContext]] has been configured to be an [[HttpsConnectionContext]].
    *
-   * @deprecated since 10.2.0: Use Http.get(system).newServerAt(interface, port).withSettings(settings).connectionSource() instead
+   * @deprecated since Akka HTTP 10.2.0: Use Http.get(system).newServerAt(interface, port).withSettings(settings).connectionSource() instead
    */
   @Deprecated
@@ -164,10 +164,10 @@ class Http(system: ExtendedActorSystem) extends pekko.actor.Extension {
    * or the [[defaultServerHttpContext]] has been configured to be an [[HttpsConnectionContext]].
    *
-   * @deprecated since 10.2.0: Use Http.get(system).newServerAt(interface, port).withSettings(settings).logTo(log).connectionSource() instead
+   * @deprecated since Akka HTTP 10.2.0: Use Http.get(system).newServerAt(interface, port).withSettings(settings).logTo(log).connectionSource() instead
    */
   @Deprecated
@@ -189,10 +189,10 @@ class Http(system: ExtendedActorSystem) extends pekko.actor.Extension {
    * or the [[defaultServerHttpContext]] has been configured to be an [[HttpsConnectionContext]].
    *
-   * @deprecated since 10.2.0: Use Http.get(system).newServerAt(interface, port).bindFlow(handler) instead.
+   * @deprecated since Akka HTTP 10.2.0: Use Http.get(system).newServerAt(interface, port).bindFlow(handler) instead.
    */
   @Deprecated
@@ -215,10 +215,10 @@ class Http(system: ExtendedActorSystem) extends pekko.actor.Extension {
    * or the [[defaultServerHttpContext]] has been configured to be an [[HttpsConnectionContext]].
    *
-   * @deprecated since 10.2.0: Use Http.get(system).newServerAt(interface, port).withSettings(settings).logTo(log).bindFlow(handler) instead.
+   * @deprecated since Akka HTTP 10.2.0: Use Http.get(system).newServerAt(interface, port).withSettings(settings).logTo(log).bindFlow(handler) instead.
    */
   @Deprecated
@@ -243,10 +243,10 @@ class Http(system: ExtendedActorSystem) extends pekko.actor.Extension {
    * or the [[defaultServerHttpContext]] has been configured to be an [[HttpsConnectionContext]].
    *
-   * @deprecated since 10.2.0: Use Http.get(system).newServerAt(interface, port).bindSync(handler) instead
+   * @deprecated since Akka HTTP 10.2.0: Use Http.get(system).newServerAt(interface, port).bindSync(handler) instead
    */
   @Deprecated
@@ -267,10 +267,10 @@ class Http(system: ExtendedActorSystem) extends pekko.actor.Extension {
    * or the [[defaultServerHttpContext]] has been configured to be an [[HttpsConnectionContext]].
    *
-   * @deprecated since 10.2.0: Use Http.get(system).newServerAt(interface, port).withSettings(settings).logTo(log).bindSync(handler) instead
+   * @deprecated since Akka HTTP 10.2.0: Use Http.get(system).newServerAt(interface, port).withSettings(settings).logTo(log).bindSync(handler) instead
    */
   @Deprecated
@@ -295,10 +295,10 @@ class Http(system: ExtendedActorSystem) extends pekko.actor.Extension {
    * or the [[defaultServerHttpContext]] has been configured to be an [[HttpsConnectionContext]].
    *
-   * @deprecated since 10.2.0: Use Http.get(system).newServerAt(interface, port).bind(handler) instead
+   * @deprecated since Akka HTTP 10.2.0: Use Http.get(system).newServerAt(interface, port).bind(handler) instead
    */
   @Deprecated
@@ -319,10 +319,10 @@ class Http(system: ExtendedActorSystem) extends pekko.actor.Extension {
    * or the [[defaultServerHttpContext]] has been configured to be an [[HttpsConnectionContext]].
    *
-   * @deprecated since 10.2.0: Use Http.get(system).newServerAt(interface, port).withSettings(settings).logTo(log).bind(handler) instead
+   * @deprecated since Akka HTTP 10.2.0: Use Http.get(system).newServerAt(interface, port).withSettings(settings).logTo(log).bind(handler) instead
    */
   @Deprecated
@@ -793,9 +793,9 @@ class Http(system: ExtendedActorSystem) extends pekko.actor.Extension {
    * Can be modified using [[setDefaultServerHttpContext]], and will then apply for servers bound after that call has completed.
    *
-   * @deprecated since 10.2.0: set context explicitly when binding
+   * @deprecated since Akka HTTP 10.2.0: set context explicitly when binding
    */
@@ -803,9 +803,9 @@ class Http(system: ExtendedActorSystem) extends pekko.actor.Extension {
    * If it is an instance of [[HttpsConnectionContext]] then the server will be bound using HTTPS.
    *
-   * @deprecated since 10.2.0: set context explicitly when binding
+   * @deprecated since Akka HTTP 10.2.0: set context explicitly when binding
    */
diff --git a/http-core/src/main/scala/org/apache/pekko/http/javadsl/model/ws/UpgradeToWebSocket.scala b/http-core/src/main/scala/org/apache/pekko/http/javadsl/model/ws/UpgradeToWebSocket.scala
index 873fdc393..e1c249bd6 100644
--- a/http-core/src/main/scala/org/apache/pekko/http/javadsl/model/ws/UpgradeToWebSocket.scala
+++ b/http-core/src/main/scala/org/apache/pekko/http/javadsl/model/ws/UpgradeToWebSocket.scala
@@ -20,10 +20,10 @@ import pekko.stream._
  * In any case, you might want to use `handleWebSocketMessages` instead as documented
  * at https://doc.akka.io/docs/akka-http/current/server-side/websocket-support.html#routing-support
  *
  * @deprecated use the WebSocketUpgrade attribute instead since 10.2.0
  */
 @Deprecated
-@deprecated("use the WebSocketUpgrade attribute instead", since = "10.2.0")
+@deprecated("use the WebSocketUpgrade attribute instead", since = "Akka HTTP 10.2.0")
 trait UpgradeToWebSocket extends sm.HttpHeader with WebSocketUpgrade {
 
   /**
@@ -20,10 +20,10 @@ import pekko.stream._
  * at https://doc.akka.io/docs/akka-http/current/server-side/websocket-support.html#routing-support
  *
- * @deprecated use the WebSocketUpgrade attribute instead since 10.2.0
+ * @deprecated use the WebSocketUpgrade attribute instead since Akka HTTP 10.2.0
  */
 @Deprecated
diff --git a/http-core/src/main/scala/org/apache/pekko/http/javadsl/settings/ServerSettings.scala b/http-core/src/main/scala/org/apache/pekko/http/javadsl/settings/ServerSettings.scala
index 7a11b3387..01ea530f8 100644
--- a/http-core/src/main/scala/org/apache/pekko/http/javadsl/settings/ServerSettings.scala
+++ b/http-core/src/main/scala/org/apache/pekko/http/javadsl/settings/ServerSettings.scala
@@ -33,10 +33,10 @@ import scala.concurrent.duration.{ Duration, FiniteDuration }
   def getPipeliningLimit: Int
 
   /**
    * @deprecated since 10.2.0, use remoteAddressAttribute instead
    */
   @Deprecated
-  @deprecated("Use remoteAddressAttribute instead", since = "10.2.0")
+  @deprecated("Use remoteAddressAttribute instead", since = "Akka HTTP 10.2.0")
   def getRemoteAddressHeader: Boolean
   def getRemoteAddressAttribute: Boolean
   def getRawRequestUriHeader: Boolean
@@ -47,7 +47,7 @@ import scala.concurrent.duration.{ Duration, FiniteDuration }
   def getSocketOptions: java.lang.Iterable[SocketOption]
   def getDefaultHostHeader: Host
   @Deprecated @deprecated("Kept for binary compatibility; Use websocketSettings.getRandomFactory instead",
-    since = "10.2.0")
+    since = "Akka HTTP 10.2.0")
   def getWebsocketRandomFactory: java.util.function.Supplier[Random]
   def getWebsocketSettings: WebSocketSettings
   def getParserSettings: ParserSettings
@@ -80,7 +80,7 @@ import scala.concurrent.duration.{ Duration, FiniteDuration }
   def withDefaultHostHeader(newValue: Host): ServerSettings = self.copy(defaultHostHeader = newValue.asScala)
   def withParserSettings(newValue: ParserSettings): ServerSettings = self.copy(parserSettings = newValue.asScala)
   @Deprecated @deprecated("Kept for binary compatibility; Use websocketSettings.withRandomFactoryFactory instead",
-    since = "10.2.0")
+    since = "Akka HTTP 10.2.0")
   def withWebsocketRandomFactory(newValue: java.util.function.Supplier[Random]): ServerSettings =
     self.copy(websocketSettings = websocketSettings.withRandomFactoryFactory(new Supplier[Random] {
       override def get(): Random = newValue.get()
@@ -33,10 +33,10 @@ import scala.concurrent.duration.{ Duration, FiniteDuration }
 
   /**
-   * @deprecated since 10.2.0, use remoteAddressAttribute instead
+   * @deprecated since Akka HTTP 10.2.0, use remoteAddressAttribute instead
    */
   @Deprecated
diff --git a/http/src/main/scala/org/apache/pekko/http/javadsl/server/directives/WebSocketDirectives.scala b/http/src/main/scala/org/apache/pekko/http/javadsl/server/directives/WebSocketDirectives.scala
index 525288012..edecfb40b 100644
--- a/http/src/main/scala/org/apache/pekko/http/javadsl/server/directives/WebSocketDirectives.scala
+++ b/http/src/main/scala/org/apache/pekko/http/javadsl/server/directives/WebSocketDirectives.scala
@@ -26,10 +26,10 @@ abstract class WebSocketDirectives extends SecurityDirectives {
   /**
    * Extract the [[UpgradeToWebSocket]] header if existent. Rejects with an [[ExpectedWebSocketRequestRejection]], otherwise.
    *
    * @deprecated use `webSocketUpgrade` instead since 10.2.0
    */
   @Deprecated
-  @deprecated("use `extractWebSocketUpgrade` instead", since = "10.2.0")
+  @deprecated("use `extractWebSocketUpgrade` instead", since = "Akka HTTP 10.2.0")
   def extractUpgradeToWebSocket(inner: JFunction[UpgradeToWebSocket, Route]): Route = RouteAdapter {
     D.extractUpgradeToWebSocket { header =>
       inner.apply(header).delegate
@@ -26,10 +26,10 @@ abstract class WebSocketDirectives extends SecurityDirectives {
    * Extract the [[UpgradeToWebSocket]] header if existent. Rejects with an [[ExpectedWebSocketRequestRejection]], otherwise.
    *
-   * @deprecated use `webSocketUpgrade` instead since 10.2.0
+   * @deprecated use `webSocketUpgrade` instead since Akka HTTP 10.2.0
    */
   @Deprecated